@@ -227,10 +227,19 @@
     # (max shown ticket in queue view)
     $Self->{'Ticket::Frontend::QueueMaxShown'} = 1200;
 
+    # Ticket::Frontend::QueueSortDefault
+    # (default sort order of the queue view / after priority sort)
+    # ASC: oldest on top, default
+    # DESC: youngest on top
+    $Self->{'Ticket::Frontend::QueueSortDefault'} = 'ASC';
+
     # Ticket::Frontend::QueueSort
-    # (sort the tickets in a single queue ascending or descending after
-    # the tickets are sorted by priority. Values: 0 = ascending (oldest
-    # on top, default), 1 = descending (youngest on top.)
+    # (sort a queue ascending or descending / after priority sort)
+    #
+    # assignment: QueueID -> Value
+    # where value is one of:
+    # 0: ascending (oldest on top, default)
+    # 1: descending (youngest on top)
     #
 #    $Self->{'Ticket::Frontend::QueueSort'} = {
 #        7 => 1,
@@ -273,21 +282,20 @@
     $Self->{'Ticket::Frontend::MoveSetState'} = 1;
 
     # Ticket::DefaultNextMoveStateType
-    # possible next states after a ticket is moved
+    # default move next state
     $Self->{'Ticket::DefaultNextMoveStateType'} = ['open', 'closed'];
 
     # Ticket::Frontend::QueueSortBy::Default
-    # (default sort criteria for all queues displaied in the QueueView
-    # after sort by priority is done.)
+    # (Queue sort by default.)
     $Self->{"Ticket::Frontend::QueueSortBy::Default"} = 'Age';
 
     # Ticket::Frontend::QueueOrder::Default
-    # (sort order for all queues in the QueueView after priority sort.)
+    # (Queue order default.)
     $Self->{"Ticket::Frontend::QueueOrder::Default"} = 'Up';
 
     # Ticket::Frontend::MailboxSortBy::Default
     # (Mailbox sort by default.)
-    $Self->{"Ticket::Frontend::MailboxSortBy::Default"} = 'Age';
+    $Self->{"Ticket::Frontend::MailboxSortBy::Default"} = 'CreateTime';
 
     # Ticket::Frontend::MailboxOrder::Default
     # (Mailbox order default.)
@@ -352,10 +360,10 @@
     $Self->{'Ticket::Frontend::PhoneSubject'} = '$Text{"Phone call at %s", "Time(DateFormatLong)"}';
     # default note text
     $Self->{'Ticket::Frontend::PhoneNote'} = '$Text{"Customer called"}';
-    # next possible states after adding a phone note
+    # next possible states after phone
     $Self->{'Ticket::PhoneDefaultNextStateType'} = ['open', 'pending auto', 'pending reminder', 'closed'];
 
-    # default next state after adding a phone note
+    # default next state
     $Self->{'Ticket::Frontend::PhoneNextState'} = 'closed successful';
     # default history type
     $Self->{'Ticket::Frontend::PhoneHistoryType'} = 'PhoneCallAgent';
@@ -364,22 +372,22 @@
     # --------------------------------------------------- #
     # Ticket Frontend Phone Ticket stuff
     # --------------------------------------------------- #
-    # default article type for a new phone ticket
+    # default article type
     $Self->{'Ticket::Frontend::PhoneNewArticleType'} = 'phone';
     $Self->{'Ticket::Frontend::PhoneNewSenderType'} = 'customer';
-    # default subject for a new phone ticket
+    # default note subject
 #    $Self->{'Ticket::Frontend::PhoneNewSubject'} = '$Text{"Phone call at %s", "Time(DateFormatLong)"}';
     $Self->{'Ticket::Frontend::PhoneNewSubject'} = '';
-    # default text for a new phone ticket
+    # default note text
 #    $Self->{'Ticket::Frontend::PhoneNewNote'} = 'New ticket via call.';
     $Self->{'Ticket::Frontend::PhoneNewNote'} = '';
-    # default next state for a new phone ticket[default: open]
+    # default next state [default: open]
     $Self->{'Ticket::Frontend::PhoneNewNextState'} = 'open';
     # Max. shown customer history tickets in phone-ticket mask.
     $Self->{'Ticket::Frontend::PhoneNewShownCustomerTickets'} = 10;
-    # default priority for a new phone ticket [default: 3 normal]
+    # default priority [default: 3 normal]
     $Self->{'Ticket::Frontend::PhonePriority'} = '3 normal';
-    # default history type for a new phone ticket
+    # default history type
     $Self->{'Ticket::Frontend::PhoneNewHistoryType'} = 'PhoneCallCustomer';
     $Self->{'Ticket::Frontend::PhoneNewHistoryComment'} = '';
 
@@ -414,29 +422,27 @@
     # Ticket Frontend Email Ticket stuff
     # --------------------------------------------------- #
     # Ticket::Frontend::EmailPriority
-    # default priority for new email tickets [default: 3 normal]
+    # default priority [default: 3 normal]
     $Self->{'Ticket::Frontend::EmailPriority'} = '3 normal';
 
     # Ticket::Frontend::EmailNewArticleType
-    # default article type for new email tickets
+    # default article type
     $Self->{'Ticket::Frontend::EmailNewArticleType'} = 'email-external';
     # Ticket::Frontend::EmailNewSenderType
-    # default sender type for new email tickets
+    # default sender type
     $Self->{'Ticket::Frontend::EmailNewSenderType'} = 'agent';
 
-    # default history type for new email tickets
+    # history
     $Self->{'Ticket::Frontend::EmailNewHistoryType'} = 'EmailAgent';
-
-    # default history comment for new email tickets
     $Self->{'Ticket::Frontend::EmailNewHistoryComment'} = '';
 
-    # default text for new email tickets
+    # default note text
     $Self->{'Ticket::Frontend::EmailNewNote'} = '';
 
-    # next possible states after an email ticket
+    # next possible states after phone
     $Self->{'Ticket::EmailDefaultNextStateType'} = ['open', 'pending auto', 'pending reminder', 'closed'];
 
-    # default next state after an email ticket
+    # default next state
     $Self->{'Ticket::Frontend::EmailNewNextState'} = 'open';
 
     # Max. shown customer history tickets in email-ticket mask.
@@ -458,7 +464,7 @@
     $Self->{'Ticket::Frontend::NoteInformAgent'} = 0;
 
     # Ticket::DefaultNextNoteStateType
-    # (default next states after adding a note)
+    # (default note next state)
     $Self->{'Ticket::DefaultNextNoteStateType'} = ['new', 'open', 'closed'];
 
     # Ticket::Frontend::NoteType
@@ -486,7 +492,7 @@
     $Self->{'Ticket::Frontend::OwnerSetState'} = 0;
 
     # Ticket::DefaultNextOwnerStateType
-    # (default next states after new owner selection)
+    # (default note next state)
     $Self->{'Ticket::DefaultNextOwnerStateType'} = ['open', 'closed'];
 
     # Ticket::Frontend::OwnerSubject
@@ -502,9 +508,9 @@
     $Self->{'Ticket::Frontend::PendingText'} = '';
     # Ticket::Frontend::PendingState
     $Self->{'Ticket::Frontend::PendingState'} = 'pending reminder';
-    # next possible states for pending screen
+    # next possible states for pendinf screen
     $Self->{'Ticket::DefaultPendingNextStateType'} = ['pending reminder', 'pending auto'];
-    # default note type for pending note
+    # default note type
     $Self->{'Ticket::Frontend::PendingNoteType'} = 'note-internal';
 
     # --------------------------------------------------- #
@@ -524,36 +530,36 @@
     # --------------------------------------------------- #
     # Ticket Frontend Ticket Compose stuff
     # --------------------------------------------------- #
-    # default next state after a ticket is composed, answered, e.g.
+    # default compose next state
     $Self->{'Ticket::DefaultNextComposeType'} = 'open';
-    # next possible states after composing / answering a ticket
+    # next possible states for compose message
     $Self->{'Ticket::DefaultNextComposeStateType'} = ['open', 'closed', 'pending auto', 'pending reminder'];
     # unix_style
-    $Self->{'Ticket::Frontend::ResponseFormat'} = '$QData{"Salutation"}
-$QData{"OrigFrom"} $Text{"wrote"}:
-$QData{"Body"}
+    $Self->{'Ticket::Frontend::ResponseFormat'} = '$Data{"Salutation"}
+$Data{"OrigFrom"} $Text{"wrote"}:
+$Data{"Body"}
 
-$QData{"StdResponse"}
+$Data{"StdResponse"}
 
-$QData{"Signature"}
+$Data{"Signature"}
 ';
     # ms_style
-#    $Self->{'Ticket::Frontend::ResponseFormat'} = '$QData{"Salutation"}
+#    $Self->{'Ticket::Frontend::ResponseFormat'} = '$Data{"Salutation"}
 #
-#$QData{"StdResponse"}
+#$Data{"StdResponse"}
 #
-#$QData{"Signature"}
+#$Data{"Signature"}
 #
-#$QData{"OrigFrom"} $Text{"wrote"}:
-#$QData{"Body"}
+#$Data{"OrigFrom"} $Text{"wrote"}:
+#$Data{"Body"}
 #';
 
     # --------------------------------------------------- #
     # Ticket Frontend Ticket Bounce stuff
     # --------------------------------------------------- #
-    # default next state after bouncing a ticket
+    # default bounce next state
     $Self->{'Ticket::Frontend::BounceState'} = 'closed successful';
-    # next possible states when a ticket is bounced
+    # next possible states for bounce message
     $Self->{'Ticket::DefaultNextBounceStateType'} = ['open', 'closed'];
     # default note text
     $Self->{'Ticket::Frontend::BounceText'} = 'Your email with ticket number "<OTRS_TICKET>" '.
@@ -568,7 +574,7 @@ $QData{"Signature"}
     # --------------------------------------------------- #
     # Ticket Frontend Ticket Forward stuff
     # --------------------------------------------------- #
-    # next possible states when forwarding a ticket
+    # next possible states for forward message
     $Self->{'Ticket::DefaultNextForwardStateType'} = ['open', 'closed'];
     # possible email type
     $Self->{'Ticket::Frontend::ForwardArticleTypes'} = [
@@ -648,7 +654,7 @@ $QData{"Signature"}
         SumRow => 1,
         UseResultCache => 1,
 #        Output => ['Print', 'CSV', 'GraphLine', 'GraphBars', 'GraphPie'],
-        Output => ['Print', 'CSV', 'GraphBars'],
+        Output => ['Print', 'CSV', 'Graph'],
         OutputDefault => 'Print',
     };
     $Self->{SystemStatsMap}->{"Ticket::Stats4"} = {
@@ -1705,4 +1711,3 @@ $QData{"Signature"}
     # Default Ticket Action ACL
     $Self->{'TicketACL::Default::Action'} = {};
 
-1;
