@@ -1,8 +1,8 @@
 # --
 # Kernel/Modules/AdminAttachment.pm - provides admin std response module
-# Copyright (C) 2001-2004 Martin Edenhofer <martin+code@otrs.org>
+# Copyright (C) 2001-2005 Martin Edenhofer <martin+code@otrs.org>
 # --
-# $Id: AdminAttachment.pm,v 1.8 2004/03/29 13:23:03 martin Exp $
+# $Id: AdminAttachment.pm,v 1.12 2005/03/27 11:50:49 martin Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -15,7 +15,7 @@ use strict;
 use Kernel::System::StdAttachment;
 
 use vars qw($VERSION);
-$VERSION = '$Revision: 1.8 $';
+$VERSION = '$Revision: 1.12 $';
 $VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
 
 # --
@@ -24,7 +24,7 @@ sub new {
     my %Param = @_;
 
     # allocate new hash for object
-    my $Self = {}; 
+    my $Self = {};
     bless ($Self, $Type);
 
     # get common opjects
@@ -34,7 +34,9 @@ sub new {
 
     # check all needed objects
     foreach (qw(ParamObject DBObject LayoutObject ConfigObject LogObject)) {
-        die "Got no $_" if (!$Self->{$_});
+        if (!$Self->{$_}) {
+            $Self->{LayoutObject}->FatalError(Message => "Got no $_!");
+        }
     }
 
     # lib object
@@ -47,7 +49,7 @@ sub Run {
     my $Self = shift;
     my %Param = @_;
     my $Output = '';
-    $Param{Subaction} = $Self->{Subaction} || ''; 
+    $Param{Subaction} = $Self->{Subaction} || '';
     $Param{NextScreen} = 'AdminAttachment';
 
     my %AttachmentIndex = $Self->{StdAttachmentObject}->GetAllStdAttachments(Valid => 0);
@@ -57,10 +59,10 @@ sub Run {
     if ($Param{Subaction} eq 'Change') {
         $Param{ID} = $Self->{ParamObject}->GetParam(Param => 'ID') || '';
         my %ResponseData = $Self->{StdAttachmentObject}->StdAttachmentGet(ID => $Param{ID});
-        $Output = $Self->{LayoutObject}->Header(Area => 'Admin', Title => 'Attachment change');
-        $Output .= $Self->{LayoutObject}->AdminNavigationBar();
+        $Output = $Self->{LayoutObject}->Header();
+        $Output .= $Self->{LayoutObject}->NavigationBar();
         $Output .= $Self->_Mask(
-            %ResponseData,  
+            %ResponseData,
             %Param,
             AttachmentIndex => \%AttachmentIndex,
         );
@@ -79,15 +81,11 @@ sub Run {
             Source => 'string',
         );
 
-        if ($Self->{StdAttachmentObject}->StdAttachmentUpdate(%GetParam, %UploadStuff, UserID => $Self->{UserID})) { 
+        if ($Self->{StdAttachmentObject}->StdAttachmentUpdate(%GetParam, %UploadStuff, UserID => $Self->{UserID})) {
             return $Self->{LayoutObject}->Redirect(OP => "Action=$Param{NextScreen}");
         }
         else {
-            $Output = $Self->{LayoutObject}->Header(Title => 'Error');
-            $Output .= $Self->{LayoutObject}->AdminNavigationBar();
-            $Output .= $Self->{LayoutObject}->Error();
-            $Output .= $Self->{LayoutObject}->Footer();
-            return $Output;
+            return $Self->{LayoutObject}->ErrorScreen();
         }
     }
     # add new response
@@ -108,11 +106,7 @@ sub Run {
              );
         }
         else {
-            $Output = $Self->{LayoutObject}->Header(Title => 'Error');
-            $Output .= $Self->{LayoutObject}->AdminNavigationBar();
-            $Output .= $Self->{LayoutObject}->Error();
-            $Output .= $Self->{LayoutObject}->Footer();
-            return $Output;
+            return $Self->{LayoutObject}->ErrorScreen();
         }
     }
     # delete response
@@ -125,17 +119,13 @@ sub Run {
              return $Self->{LayoutObject}->Redirect(OP => "Action=AdminAttachment");
         }
         else {
-            $Output = $Self->{LayoutObject}->Header(Title => 'Error');
-            $Output .= $Self->{LayoutObject}->AdminNavigationBar();
-            $Output .= $Self->{LayoutObject}->Error();
-            $Output .= $Self->{LayoutObject}->Footer();
-            return $Output;
+            return $Self->{LayoutObject}->ErrorScreen();
         }
     }
-    # else ! print form 
+    # else ! print form
     else {
-        $Output = $Self->{LayoutObject}->Header(Area => 'Admin', Title => 'Attachment add');
-        $Output .= $Self->{LayoutObject}->AdminNavigationBar();
+        $Output = $Self->{LayoutObject}->Header();
+        $Output .= $Self->{LayoutObject}->NavigationBar();
         $Output .= $Self->_Mask(
             AttachmentIndex => \%AttachmentIndex,
         );
@@ -150,12 +140,12 @@ sub _Mask {
 
     # build ValidID string
     $Param{'ValidOption'} = $Self->{LayoutObject}->OptionStrgHashRef(
-        Data => { 
+        Data => {
           $Self->{DBObject}->GetTableData(
             What => 'id, name',
             Table => 'valid',
             Valid => 0,
-          ) 
+          ),
         },
         Name => 'ValidID',
         SelectedID => $Param{ValidID},
