@@ -1,8 +1,8 @@
 # --
 # Kernel/Modules/AdminQueueResponses.pm - queue <-> responses
-# Copyright (C) 2001-2004 Martin Edenhofer <martin+code@otrs.org>
+# Copyright (C) 2001-2005 Martin Edenhofer <martin+code@otrs.org>
 # --
-# $Id: AdminQueueResponses.pm,v 1.11 2004/04/01 13:26:07 martin Exp $
+# $Id: AdminQueueResponses.pm,v 1.15 2005/11/10 22:47:30 martin Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -14,7 +14,7 @@ package Kernel::Modules::AdminQueueResponses;
 use strict;
 
 use vars qw($VERSION);
-$VERSION = '$Revision: 1.11 $';
+$VERSION = '$Revision: 1.15 $';
 $VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
 
 # --
@@ -33,7 +33,9 @@ sub new {
 
     # check all needed objects
     foreach (qw(ParamObject DBObject LayoutObject ConfigObject LogObject)) {
-        die "Got no $_" if (!$Self->{$_});
+        if (!$Self->{$_}) {
+            $Self->{LayoutObject}->FatalError(Message => "Got no $_!");
+        }
     }
 
     return $Self;
@@ -43,17 +45,17 @@ sub Run {
     my $Self = shift;
     my %Param = @_;
     my $Output = '';
-    my $Subaction = $Self->{Subaction}; 
+    my $Subaction = $Self->{Subaction};
     my $UserID = $Self->{UserID};
     my $ID = $Self->{ParamObject}->GetParam(Param => 'ID') || '';
-    $ID = $Self->{DBObject}->Quote($ID);
+    $ID = $Self->{DBObject}->Quote($ID, 'Integer') if ($ID);
     my $NextScreen = 'AdminQueueResponses';
 
     # user <-> group 1:n
     if ($Subaction eq 'Response') {
-        $Output .= $Self->{LayoutObject}->Header(Area => 'Admin', Title => 'Response <-> Queue');
-        $Output .= $Self->{LayoutObject}->AdminNavigationBar();
-        # get StdResponses data 
+        $Output .= $Self->{LayoutObject}->Header();
+        $Output .= $Self->{LayoutObject}->NavigationBar(Type => 'Admin');
+        # get StdResponses data
         my %StdResponsesData = $Self->{DBObject}->GetTableData(
                 Table => 'standard_response',
                 What => 'id, name',
@@ -71,7 +73,7 @@ sub Run {
         $Output .= $Self->_Mask(
                 FirstData => \%StdResponsesData,
                 SecondData => \%QueueData,
-                Data => \%Data,	 
+                Data => \%Data,
                 Type => 'Response',
             );
 
@@ -79,9 +81,9 @@ sub Run {
     }
     # group <-> user n:1
     elsif ($Subaction eq 'Queue') {
-        $Output .= $Self->{LayoutObject}->Header(Area => 'Admin', Title => 'Response <-> Queue');
-        $Output .= $Self->{LayoutObject}->AdminNavigationBar();
-        # get StdResponses data 
+        $Output .= $Self->{LayoutObject}->Header();
+        $Output .= $Self->{LayoutObject}->NavigationBar(Type => 'Admin');
+        # get StdResponses data
         my %StdResponsesData = $Self->{DBObject}->GetTableData(
                 Table => 'standard_response',
                 What => 'id, name',
@@ -104,7 +106,7 @@ sub Run {
             );
         $Output .= $Self->{LayoutObject}->Footer();
     }
-    # queues to standard_responses 
+    # queues to standard_responses
     elsif ($Subaction eq 'ChangeQueue') {
 
         my @NewIDs = $Self->{ParamObject}->GetArray(Param => 'IDs');
@@ -112,14 +114,14 @@ sub Run {
 
         foreach my $NewID (@NewIDs) {
             # db quote
-            $NewID = $Self->{DBObject}->Quote($NewID);
+            $NewID = $Self->{DBObject}->Quote($NewID, 'Integer');
             my $SQL = "INSERT INTO queue_standard_response (queue_id, standard_response_id, create_time, create_by, " .
 	            " change_time, change_by)" .
                 " VALUES " .
                 " ( $ID, $NewID, current_timestamp, $UserID, current_timestamp, $UserID)";
                 $Self->{DBObject}->Do(SQL => $SQL);
         }
-        $Output .= $Self->{LayoutObject}->Redirect(OP => "Action=$NextScreen");    
+        $Output .= $Self->{LayoutObject}->Redirect(OP => "Action=$NextScreen");
 
     }
     # standard_responses top queues
@@ -129,7 +131,7 @@ sub Run {
         $Self->{DBObject}->Do(SQL => "DELETE FROM queue_standard_response WHERE standard_response_id = $ID");
         foreach my $NewID (@NewIDs) {
             # db quote
-            $NewID = $Self->{DBObject}->Quote($NewID);
+            $NewID = $Self->{DBObject}->Quote($NewID, 'Integer');
             my $SQL = "INSERT INTO queue_standard_response (queue_id, standard_response_id, create_time, create_by, " .
                 " change_time, change_by)" .
                 " VALUES " .
@@ -139,22 +141,22 @@ sub Run {
         $Output .= $Self->{LayoutObject}->Redirect(OP => "Action=$NextScreen");
 
     }
-    # else ! print form 
+    # else ! print form
     else {
-        $Output .= $Self->{LayoutObject}->Header(Area => 'Admin', Title => 'Response <-> Queue');
-        $Output .= $Self->{LayoutObject}->AdminNavigationBar();
-        # get StdResponses data 
+        $Output .= $Self->{LayoutObject}->Header();
+        $Output .= $Self->{LayoutObject}->NavigationBar(Type => 'Admin');
+        # get StdResponses data
         my %StdResponsesData = $Self->{DBObject}->GetTableData(
-		Table => 'standard_response', 
-		What => 'id, name', 
+		Table => 'standard_response',
+		What => 'id, name',
 		Valid => 1);
         # get queue data
         my %QueueData = $Self->{DBObject}->GetTableData(
-                Table => 'queue', 
-                What => 'id, name', 
+                Table => 'queue',
+                What => 'id, name',
                 Valid => 1);
         $Output .= $Self->_MaskFrom(
-		FirstData => \%StdResponsesData, 
+		FirstData => \%StdResponsesData,
 		SecondData => \%QueueData);
         $Output .= $Self->{LayoutObject}->Footer();
     }
@@ -216,7 +218,7 @@ sub _MaskFrom {
     foreach (sort {$UserDataTmp{$a} cmp $UserDataTmp{$b}} keys %UserDataTmp){
         $UserDataTmp{$_} = $Self->{LayoutObject}->Ascii2Html(
             Text => $UserDataTmp{$_},
-            HTMLQuote => 1, 
+            HTMLQuote => 1,
             LanguageTranslation => 0,
         );
         $Param{AnswerQueueStrg} .= "<a href=\"$BaseLink"."Subaction=Response&ID=$_\">$UserDataTmp{$_}</a><br>";
@@ -224,7 +226,7 @@ sub _MaskFrom {
     foreach (sort {$GroupDataTmp{$a} cmp $GroupDataTmp{$b}} keys %GroupDataTmp){
         $GroupDataTmp{$_} = $Self->{LayoutObject}->Ascii2Html(
             Text => $GroupDataTmp{$_},
-            HTMLQuote => 1, 
+            HTMLQuote => 1,
             LanguageTranslation => 0,
         );
         $Param{QueueAnswerStrg}.= "<a href=\"$BaseLink"."Subaction=Queue&ID=$_\">$GroupDataTmp{$_}</a><br>";
