@@ -1,8 +1,8 @@
 # --
 # Kernel/Modules/AdminSession.pm - to control all session ids
-# Copyright (C) 2001-2004 Martin Edenhofer <martin+code@otrs.org>
+# Copyright (C) 2001-2005 Martin Edenhofer <martin+code@otrs.org>
 # --
-# $Id: AdminSession.pm,v 1.16 2004/06/25 15:36:15 martin Exp $
+# $Id: AdminSession.pm,v 1.23 2005/03/27 11:50:50 martin Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -14,7 +14,7 @@ package Kernel::Modules::AdminSession;
 use strict;
 
 use vars qw($VERSION);
-$VERSION = '$Revision: 1.16 $';
+$VERSION = '$Revision: 1.23 $';
 $VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
 
 # --
@@ -23,7 +23,7 @@ sub new {
     my %Param = @_;
 
     # allocate new hash for object
-    my $Self = {}; 
+    my $Self = {};
     bless ($Self, $Type);
 
     foreach (keys %Param) {
@@ -32,7 +32,9 @@ sub new {
 
     # check needed Opjects
     foreach (qw(ParamObject DBObject LayoutObject LogObject ConfigObject)) {
-        die "Got no $_!" if (!$Self->{$_});
+        if (!$Self->{$_}) {
+            $Self->{LayoutObject}->FatalError(Message => "Got no $_!");
+        }
     }
 
     return $Self;
@@ -41,29 +43,33 @@ sub new {
 sub Run {
     my $Self = shift;
     my %Param = @_;
-    my $Output = '';
     my $WantSessionID = $Self->{ParamObject}->GetParam(Param => 'WantSessionID') || '';
 
+    # ------------------------------------------------------------ #
     # kill session id
+    # ------------------------------------------------------------ #
     if ($Self->{Subaction} eq 'Kill') {
-        $Output .= $Self->{LayoutObject}->Redirect(OP => "Action=AdminSession");    
-        $Self->{SessionObject}->RemoveSessionID(SessionID => $WantSessionID);    
+        $Self->{SessionObject}->RemoveSessionID(SessionID => $WantSessionID);
+        return $Self->{LayoutObject}->Redirect(OP => "Action=AdminSession");
     }
+    # ------------------------------------------------------------ #
     # kill all session id
+    # ------------------------------------------------------------ #
     elsif ($Self->{Subaction} eq 'KillAll') {
-        $Output .= $Self->{LayoutObject}->Redirect(OP => "Action=AdminSession");    
         my @List = $Self->{SessionObject}->GetAllSessionIDs();
         foreach my $SessionID (@List) {
             # killall sessions but not the own one!
             if ($WantSessionID ne $SessionID) {
-                $Self->{SessionObject}->RemoveSessionID(SessionID => $SessionID);    
+                $Self->{SessionObject}->RemoveSessionID(SessionID => $SessionID);
             }
         }
+        return $Self->{LayoutObject}->Redirect(OP => "Action=AdminSession");
     }
-    # else, show session list 
+    # ------------------------------------------------------------ #
+    # else, show session list
+    # ------------------------------------------------------------ #
     else {
-        $Output .= $Self->{LayoutObject}->Header(Area => 'Admin', Title => 'Session Management');
-        $Output .= $Self->{LayoutObject}->AdminNavigationBar();
+        # get all sessions
         my @List = $Self->{SessionObject}->GetAllSessionIDs();
         my $Table = '';
         my $Counter = @List;
@@ -82,7 +88,15 @@ sub Run {
             }
             foreach (sort keys %Data) {
                 if (($_) && (defined($Data{$_})) && $_ ne 'SessionID') {
-                    $Data{$_} = $Self->{LayoutObject}->Ascii2Html(Text => $Data{$_});
+                    if ($_ =~ /^_/) {
+                        next;
+                    }
+                    if ($_ =~ /Password|Pw/) {
+                        $Data{$_} = 'xxxxxxxx';
+                    }
+                    else {
+                        $Data{$_} = $Self->{LayoutObject}->Ascii2Html(Text => $Data{$_});
+                    }
                     if ($_  eq 'UserSessionStart') {
                         my $Age = int((time() - $Data{UserSessionStart}) / 3600);
                         $Data{UserSessionStart} = scalar localtime ($Data{UserSessionStart});
@@ -101,19 +115,21 @@ sub Run {
                     Output => $List,
                     %Data,
                 },
-            ); 
+            );
         }
-        # get real template
+        # generate output
+        my $Output = $Self->{LayoutObject}->Header();
+        $Output .= $Self->{LayoutObject}->NavigationBar();
         $Output .= $Self->{LayoutObject}->Output(
-            TemplateFile => 'AdminSession', 
+            TemplateFile => 'AdminSession',
             Data => {
-                Counter => $Counter, 
+                Counter => $Counter,
                 %MetaData
             }
         );
         $Output .= $Self->{LayoutObject}->Footer();
+        return $Output;
     }
-    return $Output;
 }
 # --
 1;
