@@ -1,11 +1,11 @@
 # --
 # Kernel/Modules/AdminUserGroup.pm - to add/update/delete groups <-> users
-# Copyright (C) 2001-2004 Martin Edenhofer <martin+code@otrs.org>
+# Copyright (C) 2001-2005 Martin Edenhofer <martin+code@otrs.org>
 # --
-# $Id: AdminUserGroup.pm,v 1.17 2004/04/01 13:26:07 martin Exp $
+# $Id: AdminUserGroup.pm,v 1.22 2005/03/27 11:50:50 martin Exp $
 # --
-# This software comes with ABSOLUTELY NO WARRANTY. For details, see 
-# the enclosed file COPYING for license information (GPL). If you 
+# This software comes with ABSOLUTELY NO WARRANTY. For details, see
+# the enclosed file COPYING for license information (GPL). If you
 # did not receive this file, see http://www.gnu.org/licenses/gpl.txt.
 # --
 
@@ -14,7 +14,7 @@ package Kernel::Modules::AdminUserGroup;
 use strict;
 
 use vars qw($VERSION);
-$VERSION = '$Revision: 1.17 $';
+$VERSION = '$Revision: 1.22 $';
 $VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
 
 # --
@@ -23,7 +23,7 @@ sub new {
     my %Param = @_;
 
     # allocate new hash for object
-    my $Self = {}; 
+    my $Self = {};
     bless ($Self, $Type);
 
     # allocate new hash for objects
@@ -33,7 +33,9 @@ sub new {
 
     # check all needed objects
     foreach (qw(ParamObject DBObject QueueObject LayoutObject ConfigObject LogObject)) {
-        die "Got no $_" if (!$Self->{$_});
+        if (!$Self->{$_}) {
+            $Self->{LayoutObject}->FatalError(Message => "Got no $_!");
+        }
     }
     return $Self;
 }
@@ -41,22 +43,20 @@ sub new {
 sub Run {
     my $Self = shift;
     my %Param = @_;
-    my $Output = '';
-    my $UserID = $Self->{UserID};
     my $ID = $Self->{ParamObject}->GetParam(Param => 'ID') || '';
     $Param{NextScreen} = 'AdminUserGroup';
 
     # user <-> group 1:n
     if ($Self->{Subaction} eq 'User') {
-        $Output .= $Self->{LayoutObject}->Header(Area => 'Admin', Title => 'User <-> Groups');
-        $Output .= $Self->{LayoutObject}->AdminNavigationBar();
-        # get user data 
+        my $Output = $Self->{LayoutObject}->Header();
+        $Output .= $Self->{LayoutObject}->NavigationBar();
+        # get user data
         my %UserData = $Self->{UserObject}->GetUserData(UserID => $ID);
         # get group data
         my %GroupData = $Self->{GroupObject}->GroupList(Valid => 1);
         my %Types = ();
         foreach my $Type (@{$Self->{ConfigObject}->Get('System::Permission')}) {
-            my %Data = $Self->{GroupObject}->GroupMemberList(
+            my %Data = $Self->{GroupObject}->GroupGroupMemberList(
                 UserID => $ID,
                 Type => $Type,
                 Result => 'HASH',
@@ -65,21 +65,22 @@ sub Run {
         }
         $Output .= $Self->MaskAdminUserGroupChangeForm(
             Data => \%GroupData,
-            %Types, 
+            %Types,
             ID => $UserData{UserID},
             Name => $UserData{UserLogin},
             Type => 'User',
         );
         $Output .= $Self->{LayoutObject}->Footer();
+        return $Output;
     }
     # group <-> user n:1
     elsif ($Self->{Subaction} eq 'Group') {
-        $Output .= $Self->{LayoutObject}->Header(Area => 'Admin', Title => 'User <-> Groups');
-        $Output .= $Self->{LayoutObject}->AdminNavigationBar();
-        # get user data 
+        my $Output = $Self->{LayoutObject}->Header();
+        $Output .= $Self->{LayoutObject}->NavigationBar();
+        # get user data
         my %UserData = $Self->{UserObject}->UserList(Valid => 1);
         foreach (keys %UserData) {
-            # get user data 
+            # get user data
             my %User = $Self->{UserObject}->GetUserData(UserID => $_, Cached => 1);
             if ($User{UserFirstname} && $User{UserLastname}) {
                 $UserData{$_} .= " ($User{UserFirstname} $User{UserLastname})";
@@ -88,7 +89,7 @@ sub Run {
         # get permission list users
         my %Types = ();
         foreach my $Type (@{$Self->{ConfigObject}->Get('System::Permission')}) {
-            my %Data = $Self->{GroupObject}->GroupMemberList(
+            my %Data = $Self->{GroupObject}->GroupGroupMemberList(
                 GroupID => $ID,
                 Type => $Type,
                 Result => 'HASH',
@@ -105,6 +106,7 @@ sub Run {
             Type => 'Group',
         );
         $Output .= $Self->{LayoutObject}->Footer();
+        return $Output;
     }
     # add user to groups
     elsif ($Self->{Subaction} eq 'ChangeGroup') {
@@ -117,7 +119,7 @@ sub Run {
         # get group data
         my %UserData = $Self->{UserObject}->UserList(Valid => 1);
         my %NewPermission = ();
-        foreach (keys %UserData) { 
+        foreach (keys %UserData) {
             foreach my $Permission (keys %Permissions) {
                 $NewPermission{$Permission} = 0;
                 my @Array = @{$Permissions{$Permission}};
@@ -134,7 +136,7 @@ sub Run {
                 UserID => $Self->{UserID},
             );
         }
-        $Output .= $Self->{LayoutObject}->Redirect(OP => "Action=$Param{NextScreen}");    
+        return $Self->{LayoutObject}->Redirect(OP => "Action=$Param{NextScreen}");
     }
     # groups to user
     elsif ($Self->{Subaction} eq 'ChangeUser') {
@@ -158,22 +160,22 @@ sub Run {
                 }
             }
             $Self->{GroupObject}->GroupMemberAdd(
-                UID => $ID, 
-                GID => $_,  
+                UID => $ID,
+                GID => $_,
                 Permission => { %NewPermission },
                 UserID => $Self->{UserID},
             );
         }
-        $Output .= $Self->{LayoutObject}->Redirect(OP => "Action=$Param{NextScreen}");
+        return $Self->{LayoutObject}->Redirect(OP => "Action=$Param{NextScreen}");
     }
-    # else ! print form 
+    # else ! print form
     else {
-        $Output .= $Self->{LayoutObject}->Header(Area => 'Admin', Title => 'User <-> Groups');
-        $Output .= $Self->{LayoutObject}->AdminNavigationBar();
-        # get user data 
+        my $Output = $Self->{LayoutObject}->Header();
+        $Output .= $Self->{LayoutObject}->NavigationBar();
+        # get user data
         my %UserData = $Self->{UserObject}->UserList(Valid => 1);
         foreach (keys %UserData) {
-            # get user data 
+            # get user data
             my %User = $Self->{UserObject}->GetUserData(UserID => $_, Cached => 1);
             if ($User{UserFirstname} && $User{UserLastname}) {
                 $UserData{$_} .= " ($User{UserFirstname} $User{UserLastname})";
@@ -182,12 +184,12 @@ sub Run {
         # get group data
         my %GroupData = $Self->{GroupObject}->GroupList(Valid => 1);
         $Output .= $Self->MaskAdminUserGroupForm(
-            GroupData => \%GroupData, 
+            GroupData => \%GroupData,
             UserData => \%UserData,
         );
         $Output .= $Self->{LayoutObject}->Footer();
+        return $Output;
     }
-    return $Output;
 }
 # --
 sub MaskAdminUserGroupChangeForm {
