@@ -1,8 +1,8 @@
 # --
 # Kernel/Modules/AgentTicketZoom.pm - to get a closer view
-# Copyright (C) 2001-2006 Martin Edenhofer <martin+code@otrs.org>
+# Copyright (C) 2001-2005 Martin Edenhofer <martin+code@otrs.org>
 # --
-# $Id: AgentTicketZoom.pm,v 1.14.2.1 2006/02/03 20:22:05 martin Exp $
+# $Id: AgentTicketZoom.pm,v 1.14 2005/10/31 17:39:43 martin Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -16,7 +16,7 @@ use Kernel::System::CustomerUser;
 use Kernel::System::LinkObject;
 
 use vars qw($VERSION);
-$VERSION = '$Revision: 1.14.2.1 $';
+$VERSION = '$Revision: 1.14 $';
 $VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
 
 # --
@@ -554,7 +554,7 @@ sub MaskAgentZoom {
                 },
             );
         }
-        foreach my $FileID (sort keys %AtmIndex) {
+        foreach my $FileID (keys %AtmIndex) {
             my %File = %{$AtmIndex{$FileID}};
             $Self->{LayoutObject}->Block(
                 Name => 'ArticleAttachmentRow',
