@@ -1,8 +1,8 @@
 # --
 # Kernel/Modules/SystemStats.pm - show stats of otrs
-# Copyright (C) 2001-2006 Martin Edenhofer <martin+code@otrs.org>
+# Copyright (C) 2001-2005 Martin Edenhofer <martin+code@otrs.org>
 # --
-# $Id: SystemStats.pm,v 1.24.2.2 2006/02/01 10:23:07 martin Exp $
+# $Id: SystemStats.pm,v 1.24 2005/08/26 15:55:29 martin Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -14,7 +14,7 @@ package Kernel::Modules::SystemStats;
 use strict;
 
 use vars qw($VERSION);
-$VERSION = '$Revision: 1.24.2.2 $ ';
+$VERSION = '$Revision: 1.24 $ ';
 $VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
 
 # --
@@ -44,10 +44,7 @@ sub new {
             DatabaseDSN => $Self->{ConfigObject}->Get('Stats::DB::DSN'),
             DatabaseUser => $Self->{ConfigObject}->Get('Stats::DB::User'),
             DatabasePw => $Self->{ConfigObject}->Get('Stats::DB::Password'),
-        );
-        if (!$ExtraDatabaseObject) {
-            $Self->{LayoutObject}->FatalError();
-        }
+        ) || die $DBI::errstr;
         $Self->{TicketObject} = Kernel::System::Ticket->new(
             %Param,
             DBObject => $ExtraDatabaseObject,
@@ -329,17 +326,11 @@ sub Run {
                         Message => "Can't write png! Write: $Ext",
                     );
                 }
-                my $Content = eval { $graph->plot(\@PData)->$Ext() };
-                if (!$Content) {
-                    return $Self->{LayoutObject}->ErrorScreen(
-                        Message => "To much data, can't use it with graph!",
-                    );
-                }
                 # return image to bowser
                 return $Self->{LayoutObject}->Attachment(
                     Filename => "$ConfigItem{Module}"."_"."$Y-$M-$D"."_"."$h-$m.$Ext",
                     ContentType => "image/$Ext",
-                    Content => $Content,
+                    Content => $graph->plot(\@PData)->$Ext(),
                     Type => 'inline',
                 );
             }
