@@ -2,7 +2,7 @@
 # Kernel/Output/HTML/Generic.pm - provides generic HTML output
 # Copyright (C) 2001-2005 Martin Edenhofer <martin+code@otrs.org>
 # --
-# $Id: Generic.pm,v 1.191 2005/07/23 11:08:45 martin Exp $
+# $Id: Generic.pm,v 1.197 2005/10/31 20:10:28 martin Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -19,7 +19,7 @@ use Kernel::Output::HTML::Agent;
 use Kernel::Output::HTML::Customer;
 
 use vars qw(@ISA $VERSION);
-$VERSION = '$Revision: 1.191 $';
+$VERSION = '$Revision: 1.197 $';
 $VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
 
 @ISA = (
@@ -54,7 +54,7 @@ sub new {
     # set debug
     $Self->{Debug} = 0;
     # check needed objects
-    foreach (qw(ConfigObject LogObject)) {
+    foreach (qw(ConfigObject LogObject TimeObject MainObject)) {
         if (!$Self->{$_}) {
             $Self->{LogObject}->Log(
                 Priority => 'error',
@@ -164,13 +164,17 @@ sub new {
             $Self->{Browser} = "Unknown - $ENV{'HTTP_USER_AGENT'}";
         }
     }
-    # --
     # load theme
-    # --
     my $Theme = $Self->{UserTheme} || $Self->{ConfigObject}->Get('DefaultTheme') || 'Standard';
-    # --
+    # force a theme based on host name
+    if ($Self->{ConfigObject}->Get('DefaultTheme::HostBased') && $ENV{HTTP_HOST}) {
+        foreach (sort keys %{$Self->{ConfigObject}->Get('DefaultTheme::HostBased')}) {
+            if ($ENV{HTTP_HOST} =~ /$_/i) {
+                $Theme = $Self->{ConfigObject}->Get('DefaultTheme::HostBased')->{$_};
+            }
+        }
+    }
     # locate template files
-    # --
     $Self->{TemplateDir} = $Self->{ConfigObject}->Get('TemplateDir')."/HTML/$Theme";
     if (! -e $Self->{TemplateDir}) {
         $Self->{LogObject}->Log(
@@ -628,7 +632,7 @@ sub Output {
         # --
         foreach (1..3) {
             $Line =~ s{
-                \$(QData|LQData|Data|Env|Config|Include){"(.+?)"}
+                \$(QData|LQData|Data|Env|QEnv|Config|Include){"(.+?)"}
             }
             {
               if ($1 eq "Data" || $1 eq "Env") {
@@ -640,6 +644,30 @@ sub Output {
                       "";
                   }
               }
+              elsif ($1 eq "QEnv") {
+                  my $Text = $2;
+                  if (!defined($Text) || $Text =~ /^","(.+?)$/) {
+                      "";
+                  }
+                  elsif ($Text =~ /^(.+?)","(.+?)$/) {
+                      if (defined $GlobalRef->{"EnvRef"}->{$1}) {
+                          $Self->Ascii2Html(Text => $GlobalRef->{"EnvRef"}->{$1}, Max => $2);
+                      }
+                      else {
+                          # output replace with nothing!
+                          "";
+                      }
+                  }
+                  else {
+                      if (defined $GlobalRef->{"EnvRef"}->{$Text}) {
+                          $Self->Ascii2Html(Text => $GlobalRef->{"EnvRef"}->{$Text});
+                      }
+                      else {
+                          # output replace with nothing!
+                          "";
+                      }
+                  }
+              }
               elsif ($1 eq "QData") {
                   my $Text = $2;
                   if (!defined($Text) || $Text =~ /^","(.+?)$/) {
@@ -647,20 +675,20 @@ sub Output {
                   }
                   elsif ($Text =~ /^(.+?)","(.+?)$/) {
                       if (defined $GlobalRef->{"DataRef"}->{$1}) {
-                        $Self->Ascii2Html(Text => $GlobalRef->{"DataRef"}->{$1}, Max => $2);
+                          $Self->Ascii2Html(Text => $GlobalRef->{"DataRef"}->{$1}, Max => $2);
                       }
                       else {
-                        # output replace with nothing!
-                        "";
+                          # output replace with nothing!
+                          "";
                       }
                   }
                   else {
                       if (defined $GlobalRef->{"DataRef"}->{$Text}) {
-                        $Self->Ascii2Html(Text => $GlobalRef->{"DataRef"}->{$Text});
+                          $Self->Ascii2Html(Text => $GlobalRef->{"DataRef"}->{$Text});
                       }
                       else {
-                        # output replace with nothing!
-                        "";
+                          # output replace with nothing!
+                          "";
                       }
                   }
               }
@@ -1245,6 +1273,7 @@ sub Ascii2Html {
     $Text =~ s/</&lt;/g;
     $Text =~ s/>/&gt;/g;
     $Text =~ s/"/&quot;/g;
+#    $Text =~ s/'/&apos;/g;
     # text -> html format quoting
     if ($HTMLMode) {
         $Text =~ s/\n/<br>\n/g;
@@ -1699,7 +1728,13 @@ sub Attachment {
         $Output .= '; ';
     }
     $Output .= "filename=\"$Param{Filename}\"\n";
-    $Output .= "Content-Length: ".length($Param{Content})."\n";
+    # get attachment size
+    {
+        use bytes;
+        $Param{Size} = length($Param{Content});
+        no bytes;
+    }
+    $Output .= "Content-Length: $Param{Size}\n";
     $Output .= "Content-Type: $Param{ContentType}\n\n";
     # fix for firefox HEAD problem
     if (!$ENV{REQUEST_METHOD} || $ENV{REQUEST_METHOD} ne 'HEAD') {
@@ -2027,9 +2062,9 @@ sub BuildDateSelection {
     my $DiffTime = $Param{'DiffTime'} || 0;
     my $Format = defined($Param{Format}) ? $Param{Format} : 'DateInputFormatLong';
     my $Area = $Param{Area} || 'Agent';
-    my ($s,$m,$h, $D,$M,$Y, $wd,$yd,$dst) = localtime(time()+$DiffTime);
-    $Y = $Y+1900;
-    $M++;
+    my ($s,$m,$h, $D,$M,$Y) = $Self->{TimeObject}->SystemTime2Date(
+        SystemTime => $Self->{TimeObject}->SystemTime() + $DiffTime,
+    );
     # year
     if ($DateInputStyle eq 'Option') {
         my %Year = ();
@@ -2088,7 +2123,7 @@ sub BuildDateSelection {
             $Param{Hour} = $Self->OptionStrgHashRef(
                 Name => $Prefix.'Hour',
                 Data => \%Hour,
-                SelectedID => defined($Param{$Prefix.'Hour'}) ? int($Param{$Prefix.'Hour'}) : $h,
+                SelectedID => defined($Param{$Prefix.'Hour'}) ? int($Param{$Prefix.'Hour'}) : int($h),
             );
         }
         else {
@@ -2104,7 +2139,7 @@ sub BuildDateSelection {
             $Param{Minute} = $Self->OptionStrgHashRef(
                 Name => $Prefix.'Minute',
                 Data => \%Minute,
-                SelectedID => defined($Param{$Prefix.'Minute'}) ? int($Param{$Prefix.'Minute'}) : $m,
+                SelectedID => defined($Param{$Prefix.'Minute'}) ? int($Param{$Prefix.'Minute'}) : int($m),
             );
         }
         else {
@@ -2257,6 +2292,6 @@ did not receive this file, see http://www.gnu.org/licenses/gpl.txt.
 
 =head1 VERSION
 
-$Revision: 1.191 $ $Date: 2005/07/23 11:08:45 $
+$Revision: 1.197 $ $Date: 2005/10/31 20:10:28 $
 
 =cut
