@@ -1,8 +1,8 @@
 # --
 # Kernel/System/CustomerUser.pm - some customer user functions
-# Copyright (C) 2001-2006 Martin Edenhofer <martin+code@otrs.org>
+# Copyright (C) 2001-2005 Martin Edenhofer <martin+code@otrs.org>
 # --
-# $Id: CustomerUser.pm,v 1.22.2.4 2006/04/28 11:59:03 tr Exp $
+# $Id: CustomerUser.pm,v 1.22 2005/10/20 21:27:51 martin Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -14,7 +14,7 @@ package Kernel::System::CustomerUser;
 use strict;
 
 use vars qw(@ISA $VERSION);
-$VERSION = '$Revision: 1.22.2.4 $';
+$VERSION = '$Revision: 1.22 $';
 $VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
 
 =head1 NAME
@@ -101,7 +101,7 @@ sub new {
 
 =item CustomerSourceList()
 
-return customer source list
+return customer soruce list
 
   my %List = $CustomerUserObject->CustomerSourceList();
 
@@ -125,17 +125,17 @@ to search users
 
   my %List = $CustomerUserObject->CustomerSearch(
       Search => '*some*', # also 'hans+huber' possible
-      ValidID => 1, # not required, default 1
+      ValidID => 1, # not required
   );
 
   my %List = $CustomerUserObject->CustomerSearch(
       UserLogin => '*some*',
-      ValidID => 1, # not required, default 1
+      ValidID => 1, # not required
   );
 
   my %List = $CustomerUserObject->CustomerSearch(
       PostMasterSearch => 'email@example.com',
-      ValidID => 1, # not required, default 1
+      ValidID => 1, # not required
   );
 
 =cut
@@ -160,7 +160,7 @@ sub CustomerSearch {
 
 =item CustomerUserList()
 
-return a hash with all users (depreciated)
+return a hash with all users
 
   my %List = $CustomerUserObject->CustomerUserList(
       Valid => 1, # not required
@@ -263,11 +263,10 @@ sub CustomerUserDataGet {
 
 to add new customer users
 
-  my $UserLogin = $CustomerUserObject->CustomerUserAdd(
+  my $UserID = $CustomerUserObject->CustomerUserAdd(
       Source => 'CustomerUser', # CustomerUser source config
       UserFirstname => 'Huber',
       UserLastname => 'Manfred',
-      UserCustomerID => 'A124',
       UserLogin => 'mhuber',
       UserPassword => 'some-pass', # not required
       UserEmail => 'email@example.com',
@@ -285,14 +284,14 @@ sub CustomerUserAdd {
         $Param{Source} = 'CustomerUser';
     }
     # check if user exists
-    if ($Param{UserLogin}) {
-        my %User = $Self->CustomerUserDataGet(User => $Param{UserLogin});
-        if (%User) {
-           $Self->{LogObject}->Log(Priority => 'error', Message => "User already exists '$Param{UserLogin}'!");
-           return;
-        }
+    my %User = $Self->CustomerUserDataGet(User => $Param{UserLogin});
+    if (%User) {
+        $Self->{LogObject}->Log(Priority => 'error', Message => "User already exists '$Param{UserLogin}'!");
+        return;
+    }
+    else {
+        return $Self->{$Param{Source}}->CustomerUserAdd(@_);
     }
-    return $Self->{$Param{Source}}->CustomerUserAdd(@_);
 }
 
 =item CustomerUserUpdate()
@@ -423,6 +422,6 @@ did not receive this file, see http://www.gnu.org/licenses/gpl.txt.
 
 =head1 VERSION
 
-$Revision: 1.22.2.4 $ $Date: 2006/04/28 11:59:03 $
+$Revision: 1.22 $ $Date: 2005/10/20 21:27:51 $
 
 =cut
