@@ -2,7 +2,7 @@
 # Kernel/System/CustomerUser/DB.pm - some customer user functions
 # Copyright (C) 2001-2004 Martin Edenhofer <martin+code@otrs.org>
 # --
-# $Id: DB.pm,v 1.32.2.1 2004/09/16 08:06:01 martin Exp $
+# $Id: DB.pm,v 1.36 2004/12/28 01:03:00 martin Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -15,7 +15,7 @@ use strict;
 use Kernel::System::CheckItem;
 
 use vars qw(@ISA $VERSION);
-$VERSION = '$Revision: 1.32.2.1 $';
+$VERSION = '$Revision: 1.36 $';
 $VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
 
 # --
@@ -41,6 +41,7 @@ sub new {
     $Self->{CustomerID} = $Self->{CustomerUserMap}->{CustomerID}
       || die "Need CustomerUser->CustomerID in Kernel/Config.pm!";
     $Self->{ReadOnly} = $Self->{CustomerUserMap}->{ReadOnly};
+    $Self->{ExcludePrimaryCustomerID} = $Self->{CustomerUserMap}->{CustomerUserExcludePrimaryCustomerID} || 0;
     $Self->{SearchPrefix} = $Self->{CustomerUserMap}->{'CustomerUserSearchPrefix'};
     if (!defined($Self->{SearchPrefix})) {
         $Self->{SearchPrefix} = '';
@@ -146,14 +147,14 @@ sub CustomerSearch {
                     if ($SQLExt) {
                         $SQLExt .= ' OR ';
                     }
-                    $SQLExt .= " $_ LIKE '".$Self->{DBObject}->Quote($Part)."' ";
+                    $SQLExt .= " LOWER($_) LIKE LOWER('".$Self->{DBObject}->Quote($Part)."') ";
                 }
                 if ($SQLExt) {
                     $SQL .= "($SQLExt)";
                 }
             }
             else {
-                $SQL .= " $Self->{CustomerKey} LIKE '".$Self->{DBObject}->Quote($Part)."' ";
+                $SQL .= " LOWER($Self->{CustomerKey}) LIKE LOWER('".$Self->{DBObject}->Quote($Part)."') ";
             }
         }
     }
@@ -164,14 +165,14 @@ sub CustomerSearch {
                 if ($SQLExt) {
                     $SQLExt .= ' OR ';
                 }
-                $SQLExt .= " $_ LIKE '".$Self->{DBObject}->Quote($Param{PostMasterSearch})."' ";
+                $SQLExt .= " LOWER($_) LIKE LOWER('".$Self->{DBObject}->Quote($Param{PostMasterSearch})."') ";
             }
             $SQL .= $SQLExt;
         }
     }
     elsif ($Param{UserLogin}) {
         $Param{UserLogin} =~ s/\*/%/g;
-        $SQL .= " $Self->{CustomerKey} LIKE '".$Self->{DBObject}->Quote($Param{UserLogin})."'";
+        $SQL .= " LOWER($Self->{CustomerKey}) LIKE LOWER('".$Self->{DBObject}->Quote($Param{UserLogin})."')";
     }
     # add valid option
     if ($Self->{CustomerUserMap}->{CustomerValid} && $Valid) {
@@ -237,7 +238,7 @@ sub CustomerIDs {
         }
     }
     # use also the primary customer id
-    if ($Data{UserCustomerID}) {
+    if ($Data{UserCustomerID} && !$Self->{ExcludePrimaryCustomerID}) {
         push (@CustomerIDs, $Data{UserCustomerID});
     }
     return @CustomerIDs;
@@ -377,7 +378,9 @@ sub CustomerUserAdd {
           Message => "CustomerUser: '$Param{UserLogin}' created successfully ($Param{UserID})!",
       );
       # set password
-      $Self->SetPassword(UserLogin => $Param{UserLogin}, PW => $Param{UserPassword});
+      if ($Param{UserPassword}) {
+          $Self->SetPassword(UserLogin => $Param{UserLogin}, PW => $Param{UserPassword});
+      }
       return $Param{UserLogin};
     }
     else {
@@ -395,7 +398,7 @@ sub CustomerUserUpdate {
     }
     # check needed stuff
     foreach my $Entry (@{$Self->{CustomerUserMap}->{Map}}) {
-      if (!$Param{$Entry->[0]} && $Entry->[4]) {
+      if (!$Param{$Entry->[0]} && $Entry->[4] && $Entry->[0] ne 'UserPassword') {
         $Self->{LogObject}->Log(Priority => 'error', Message => "Need $Entry->[0]!");
         return;
       }
@@ -432,8 +435,7 @@ sub CustomerUserUpdate {
             Message => "CustomerUser: '$Param{UserLogin}' updated successfully ($Param{UserID})!",
         );
         # check pw
-        my $GetPw = $UserData{UserPassword} || '';
-        if ($GetPw ne $Param{UserPassword}) {
+        if ($Param{UserPassword}) {
             $Self->SetPassword(UserLogin => $Param{UserLogin}, PW => $Param{UserPassword});
         }
         return 1;
