@@ -2,7 +2,7 @@
 # Kernel/System/DB.pm - the global database wrapper to support different databases
 # Copyright (C) 2001-2005 Martin Edenhofer <martin+code@otrs.org>
 # --
-# $Id: DB.pm,v 1.40.2.2 2005/11/20 21:30:49 martin Exp $
+# $Id: DB.pm,v 1.47 2005/11/07 15:28:31 martin Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -13,10 +13,11 @@ package Kernel::System::DB;
 
 use strict;
 use DBI;
+use Kernel::System::Time;
 use Kernel::System::Encode;
 
 use vars qw(@ISA $VERSION);
-$VERSION = '$Revision: 1.40.2.2 $';
+$VERSION = '$Revision: 1.47 $';
 $VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
 
 =head1 NAME
@@ -63,7 +64,6 @@ create database object with database connect
 
 =cut
 
-# --
 sub new {
     my $Type = shift;
     my %Param = @_;
@@ -86,6 +86,8 @@ sub new {
     }
     # encode object
     $Self->{EncodeObject} = Kernel::System::Encode->new(%Param);
+    # time object
+    $Self->{TimeObject} = Kernel::System::Time->new(%Param);
     # get config data
     $Self->{DSN}  = $Param{DatabaseDSN} || $Self->{ConfigObject}->Get('DatabaseDSN');
     $Self->{USER} = $Param{DatabaseUser} || $Self->{ConfigObject}->Get('DatabaseUser');
@@ -107,103 +109,47 @@ sub new {
     elsif ($Self->{DSN} =~ /:pg/i) {
         $Self->{'DB::Type'} = 'postgresql';
     }
-    elsif ($Self->{DSN} =~ /:db2/i) {
-        $Self->{'DB::Type'} = 'db2';
-    }
     elsif ($Self->{DSN} =~ /:oracle/i) {
         $Self->{'DB::Type'} = 'oracle';
     }
-    elsif ($Self->{DSN} =~ /:odbc/i) {
-        $Self->{'DB::Type'} = 'odbc';
+    elsif ($Self->{DSN} =~ /:sapdb/i) {
+        $Self->{'DB::Type'} = 'maxdb';
     }
-    else {
-        $Self->{'DB::Type'} = 'generic';
+    elsif ($Self->{DSN} =~ /:maxdb/i) {
+        $Self->{'DB::Type'} = 'maxdb';
     }
+    elsif ($Self->{DSN} =~ /:db2/i) {
+        $Self->{'DB::Type'} = 'db2';
+    }
+
     # get database type (config option)
     if ($Self->{ConfigObject}->Get("Database::Type")) {
         $Self->{'DB::Type'} = $Self->{ConfigObject}->Get("Database::Type");
     }
+    # get database type (overwrite with params)
     if ($Param{Type}) {
         $Self->{'DB::Type'} = $Param{Type};
     }
-    # set database functions
-    if ($Self->{'DB::Type'} eq 'mysql') {
-        $Self->{'DB::Limit'} = 'limit';
-        $Self->{'DB::DirectBlob'} = 1;
-        $Self->{'DB::QuoteSignle'} = '\\';
-        $Self->{'DB::QuoteBack'} = '\\';
-        $Self->{'DB::QuoteSemicolon'} = '\\';
-        $Self->{'DB::Attribute'} = {};
-    }
-    elsif ($Self->{'DB::Type'} eq 'postgresql') {
-        $Self->{'DB::Limit'} = 'limit';
-        $Self->{'DB::DirectBlob'} = 0;
-        $Self->{'DB::QuoteSignle'} = '\\';
-        $Self->{'DB::QuoteBack'} = '\\';
-        $Self->{'DB::QuoteSemicolon'} = '\\';
-        $Self->{'DB::Attribute'} = {};
-    }
-    elsif ($Self->{'DB::Type'} eq 'oracle') {
-        $Self->{'DB::Limit'} = 0;
-        $Self->{'DB::DirectBlob'} = 0;
-        $Self->{'DB::QuoteSignle'} = '\'';
-        $Self->{'DB::QuoteBack'} = 0;
-        $Self->{'DB::QuoteSemicolon'} = '';
-        $Self->{'DB::Attribute'} = {
-            LongTruncOk => 1,
-            LongReadLen => 100*1024,
-        };
-    }
-    elsif ($Self->{'DB::Type'} eq 'db2') {
-        $Self->{'DB::Limit'} = 'fetch';
-        $Self->{'DB::DirectBlob'} = 0;
-        $Self->{'DB::QuoteSignle'} = '\\';
-        $Self->{'DB::QuoteBack'} = '\\';
-        $Self->{'DB::QuoteSemicolon'} = '\\';
-        $Self->{'DB::Attribute'} = {};
-    }
-    elsif ($Self->{'DB::Type'} eq 'sapdb') {
-        $Self->{'DB::Limit'} = 0;
-        $Self->{'DB::DirectBlob'} = 0;
-        $Self->{'DB::QuoteSignle'} = '\'';
-        $Self->{'DB::QuoteBack'} = 0;
-        $Self->{'DB::QuoteSemicolon'} = '\'';
-        $Self->{'DB::Attribute'} = {
-            LongTruncOk => 1,
-            LongReadLen => 100*1024,
-        };
-        $Self->{'DB::CurrentTimestamp'} = 'timestamp';
-    }
-    elsif ($Self->{'DB::Type'} eq 'mssql') {
-        $Self->{'DB::Limit'} = 0;
-        $Self->{'DB::DirectBlob'} = 0;
-        $Self->{'DB::QuoteSignle'} = '\'';
-        $Self->{'DB::QuoteBack'} = 0;
-        $Self->{'DB::QuoteSemicolon'} = '\'';
-        $Self->{'DB::Attribute'} = {
-            LongTruncOk => 1,
-            LongReadLen => 100*1024,
-        };
-    }
-    elsif ($Self->{'DB::Type'} eq 'generic') {
-        $Self->{'DB::Limit'} = 0;
-        $Self->{'DB::DirectBlob'} = 0;
-        $Self->{'DB::QuoteSignle'} = '\\';
-        $Self->{'DB::QuoteBack'} = '\\';
-        $Self->{'DB::QuoteSemicolon'} = '\\';
-        $Self->{'DB::Attribute'} = {
-            LongTruncOk => 1,
-            LongReadLen => 100*1024,
-        };
+
+    # load backend module
+    if ($Self->{'DB::Type'}) {
+        my $GenericModule = "Kernel::System::DB::$Self->{'DB::Type'}";
+        if (!eval "require $GenericModule") {
+            die "Can't load database backend module $GenericModule! $@";
+        }
+        @ISA = ($GenericModule);
+        # set database functions
+        $Self->LoadPreferences();
     }
     else {
         $Self->{LogObject}->Log(
-          Priority => 'Error',
-          Message => "Unknown database type $Self->{'DB::Type'}! Set ".
-              "option Database::Type to (mysql|postgresql|db2|sapdb|oracle|mssql|generic)."
+            Priority => 'Error',
+            Message => "Unknown database type! Set option Database::Type in ".
+              "Kernel/Config.pm to (mysql|postgresql|maxdb|oracle|db2|mssql).",
         );
         return;
     }
+
     # check/get extra database config options
     # (overwrite auto detection with config options)
     foreach (qw(Type Limit DirectBlob Attribute QuoteSingle QuoteBack)) {
@@ -278,8 +224,8 @@ sub Disconnect {
 
 to quote sql params
 
-  quote strings, date and time:
-  =============================
+  quote strings:
+  ==============
   my $DBString = $DBObject->Quote("This isn't a problem!");
 
   quote integers:
@@ -290,7 +236,6 @@ to quote sql params
   ==========================================
   my $DBString = $DBObject->Quote(1234, 'Number');
 
-
 =cut
 
 sub Quote {
@@ -300,6 +245,7 @@ sub Quote {
     if (!defined $Text) {
         return;
     }
+
     # do quote integer
     if ($Type && $Type eq 'Integer') {
         if ($Text !~ /^\d{1,16}$/) {
@@ -329,8 +275,8 @@ sub Quote {
         if ($Self->{'DB::QuoteBack'}) {
             $Text =~ s/\\/$Self->{'DB::QuoteBack'}\\/g;
         }
-        if ($Self->{'DB::QuoteSignle'}) {
-            $Text =~ s/'/$Self->{'DB::QuoteSignle'}'/g;
+        if ($Self->{'DB::QuoteSingle'}) {
+            $Text =~ s/'/$Self->{'DB::QuoteSingle'}'/g;
         }
         if ($Self->{'DB::QuoteSemicolon'}) {
             $Text =~ s/;/$Self->{'DB::QuoteSemicolon'};/g;
@@ -346,7 +292,6 @@ sub Quote {
         return '';
     }
 }
-# --
 
 =item Error()
 
@@ -360,7 +305,6 @@ sub Error {
     my $Self = shift;
     return $DBI::errstr;
 }
-# --
 
 =item Do()
 
@@ -386,9 +330,12 @@ to insert, update or delete something
 sub Do {
     my $Self = shift;
     my %Param = @_;
-    my $SQL = $Param{SQL};
-    my $BindArray = $Param{Bind};
     my @Array = ();
+    # check needed stuff
+    if (!$Param{SQL}) {
+        $Self->{LogObject}->Log(Priority => 'error', Message => "Need SQL!");
+        return;
+    }
     # check bind params
     if ($Param{Bind}) {
         foreach my $Data (@{$Param{Bind}}) {
@@ -405,9 +352,16 @@ sub Do {
             }
         }
     }
-    # doing timestamp workaround (if needed)
-    if ($Self->{'DB::CurrentTimestamp'}) {
-        $SQL =~ s/current_timestamp/$Self->{'DB::CurrentTimestamp'}/g;
+    if (!$Self->{ConfigObject}->Get('TimeZone')) {
+        # doing timestamp workaround (if needed)
+        if ($Self->{'DB::CurrentTimestamp'}) {
+            $Param{SQL} =~ s/current_timestamp/$Self->{'DB::CurrentTimestamp'}/g;
+        }
+    }
+    else {
+        # replace current_timestamp
+        my $Timestamp = $Self->{TimeObject}->CurrentTimestamp();
+        $Param{SQL} =~ s/(\s|\(|,| )current_timestamp(\s|\)|,| )/$1'$Timestamp'$2/g;
     }
     # debug
     if ($Self->{Debug} > 0) {
@@ -415,21 +369,20 @@ sub Do {
         $Self->{LogObject}->Log(
           Caller => 1,
           Priority => 'debug',
-          Message => "DB.pm->Do ($Self->{DoCounter}) SQL: '$SQL'",
+          Message => "DB.pm->Do ($Self->{DoCounter}) SQL: '$Param{SQL}'",
         );
     }
     # send sql to database
-    if (!$Self->{dbh}->do($SQL, undef, @Array)) {
+    if (!$Self->{dbh}->do($Param{SQL}, undef, @Array)) {
         $Self->{LogObject}->Log(
           Caller => 1,
           Priority => 'Error',
-          Message => "$DBI::errstr, SQL: '$SQL'",
+          Message => "$DBI::errstr, SQL: '$Param{SQL}'",
         );
         return;
     }
     return 1;
 }
-# --
 
 =item Prepare()
 
@@ -447,6 +400,11 @@ sub Prepare {
     my %Param = @_;
     my $SQL = $Param{SQL};
     my $Limit = $Param{Limit} || '';
+    # check needed stuff
+    if (!$Param{SQL}) {
+        $Self->{LogObject}->Log(Priority => 'error', Message => "Need SQL!");
+        return;
+    }
     $Self->{Limit} = 0;
     $Self->{LimitCounter} = 0;
     # build finally select query
@@ -489,7 +447,6 @@ sub Prepare {
     }
     return 1;
 }
-# --
 
 =item FetchrowArray()
 
@@ -539,7 +496,6 @@ sub FetchrowHashref {
     # return
     return $Self->{Curser}->fetchrow_hashref();
 }
-# --
 
 =item GetDatabaseFunction()
 
@@ -554,7 +510,115 @@ sub GetDatabaseFunction {
     my $What = shift;
     return $Self->{'DB::'.$What};
 }
-# --
+
+=item SQLProcessor()
+
+generate database based sql syntax (e. g. CREATE TABLE ...)
+
+  my @SQL = $DBObject->SQLProcessor(
+    Database =>
+      [
+         Tag => 'TableCreate',
+         Name => 'table_name',
+      ],
+      [
+         Tag => 'Column',
+         Name => 'col_name',
+         Type => 'VARCHAR',
+         Size => 150,
+      ],
+      [
+         Tag => 'Column',
+         Name => 'col_name2',
+         Type => 'INTERGER',
+      ],
+      [
+         Tag => 'TableEnd',
+      ],
+  );
+
+=cut
+
+sub SQLProcessor {
+    my $Self = shift;
+    my %Param = @_;
+    my @SQL = ();
+    if ($Param{Database} && ref($Param{Database}) eq 'ARRAY') {
+        my @Table = ();
+        foreach my $Tag (@{$Param{Database}}) {
+#            print STDERR "$Tag->{Tag} $Tag->{TagType}------\n";
+            if (($Tag->{Tag} eq 'Table' || $Tag->{Tag} eq 'TableCreate') && $Tag->{TagType} eq 'Start') {
+                push (@Table, $Tag);
+            }
+            elsif (($Tag->{Tag} eq 'Table' || $Tag->{Tag} eq 'TableCreate') && $Tag->{TagType} eq 'End') {
+                push (@Table, $Tag);
+                push (@SQL, $Self->TableCreate(@Table));
+                @Table = ();
+            }
+            elsif ($Tag->{Tag} eq 'Column' && $Tag->{TagType} eq 'Start') {
+                push (@Table, $Tag);
+            }
+            elsif ($Tag->{Tag} eq 'Unique' && $Tag->{TagType} eq 'Start') {
+                push (@Table, $Tag);
+            }
+            elsif ($Tag->{Tag} eq 'UniqueColumn' && $Tag->{TagType} eq 'Start') {
+                push (@Table, $Tag);
+            }
+            elsif ($Tag->{Tag} eq 'Index' && $Tag->{TagType} eq 'Start') {
+                push (@Table, $Tag);
+            }
+            elsif ($Tag->{Tag} eq 'IndexColumn' && $Tag->{TagType} eq 'Start') {
+                push (@Table, $Tag);
+            }
+            elsif ($Tag->{Tag} eq 'ForeignKey' && $Tag->{TagType} eq 'Start') {
+                push (@Table, $Tag);
+            }
+            elsif ($Tag->{Tag} eq 'Reference' && $Tag->{TagType} eq 'Start') {
+                push (@Table, $Tag);
+            }
+            elsif ($Tag->{Tag} eq 'TableDrop' && $Tag->{TagType} eq 'Start') {
+                push (@Table, $Tag);
+                push (@SQL, $Self->TableDrop(@Table));
+                @Table = ();
+            }
+            elsif ($Tag->{Tag} eq 'Insert' && $Tag->{TagType} eq 'Start') {
+                push (@Table, $Tag);
+            }
+            elsif ($Tag->{Tag} eq 'Data' && $Tag->{TagType} eq 'Start') {
+                push (@Table, $Tag);
+            }
+            elsif ($Tag->{Tag} eq 'Insert' && $Tag->{TagType} eq 'End') {
+                push (@Table, $Tag);
+                push (@SQL, $Self->Insert(@Table));
+                @Table = ();
+            }
+        }
+    }
+    return @SQL;
+}
+
+=item SQLProcessorPost()
+
+generate database based sql syntax, post data of SQLProcessor(),
+e. g. foreign keys
+
+  my @SQL = $DBObject->SQLProcessorPost();
+
+=cut
+
+sub SQLProcessorPost {
+    my $Self = shift;
+    my %Param = @_;
+    my @SQL = ();
+    if ($Self->{Post}) {
+        my @Return = @{$Self->{Post}};
+        undef $Self->{Post};
+        return @Return;
+    }
+    else {
+        return ();
+    }
+}
 
 =item GetTableData()
 
@@ -603,7 +667,7 @@ sub GetTableData {
     }
     return %Data;
 }
-# --
+
 sub GetValidIDs {
     my $Self = shift;
     my %Param = @_;
@@ -621,12 +685,11 @@ sub GetValidIDs {
     }
     return @ValidIDs;
 }
-# --
+
 sub DESTROY {
     my $Self = shift;
     $Self->Disconnect();
 }
-# --
 1;
 
 =head1 TERMS AND CONDITIONS
@@ -641,7 +704,6 @@ did not receive this file, see http://www.gnu.org/licenses/gpl.txt.
 
 =head1 VERSION
 
-$Revision: 1.40.2.2 $ $Date: 2005/11/20 21:30:49 $
+$Revision: 1.47 $ $Date: 2005/11/07 15:28:31 $
 
 =cut
-
