@@ -2,7 +2,7 @@
 # Kernel/System/FAQ.pm - all faq funktions
 # Copyright (C) 2001-2005 Martin Edenhofer <martin+code@otrs.org>
 # --
-# $Id: FAQ.pm,v 1.23 2005/08/19 15:37:47 martin Exp $
+# $Id: FAQ.pm,v 1.27 2005/11/05 11:59:52 martin Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -15,7 +15,7 @@ use strict;
 use MIME::Base64;
 
 use vars qw(@ISA $VERSION);
-$VERSION = '$Revision: 1.23 $';
+$VERSION = '$Revision: 1.27 $';
 $VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
 
 =head1 NAME
@@ -94,8 +94,8 @@ sub FAQGet {
       }
     }
     # db quote
-    foreach (keys %Param) {
-        $Param{$_} = $Self->{DBObject}->Quote($Param{$_});
+    foreach (qw(FAQID)) {
+        $Param{$_} = $Self->{DBObject}->Quote($Param{$_}, 'Integer');
     }
     my %Data = ();
     my $SQL = "SELECT i.f_name, i.f_language_id, i.f_subject, ".
@@ -143,6 +143,10 @@ sub FAQGet {
             Number => $Row[27],
         );
     }
+    if (!%Data) {
+        $Self->{LogObject}->Log(Priority => 'error', Message => "No such FAQID $Param{FAQID}!");
+        return;
+    }
     # update number
     if (!$Data{Number}) {
         my $Number = $Self->{ConfigObject}->Get('SystemID')."00".$Data{FAQID};
@@ -212,8 +216,11 @@ sub FAQAdd {
         $Param{Number} = $Self->{ConfigObject}->Get('SystemID').rand(100);
     }
     # db quote (just not Content, use db Bind values)
-    foreach (keys %Param) {
-        $Param{$_} = $Self->{DBObject}->Quote($Param{$_}) if ($_ ne 'Content');
+    foreach (qw(Number Name Title Keywords Field1 Field2 Field3 Field4 Field5 Field6 FreeKey1 FreeText1 FreeKey2 FreeText2 FreeKey3 FreeText3 FreeKey4 FreeText4 Filename ContentType Filesize)) {
+        $Param{$_} = $Self->{DBObject}->Quote($Param{$_});
+    }
+    foreach (qw(CategoryID StateID LanguageID)) {
+        $Param{$_} = $Self->{DBObject}->Quote($Param{$_}, 'Integer');
     }
 
     foreach my $Type (qw(Field FreeKey FreeText)) {
@@ -331,8 +338,11 @@ sub FAQUpdate {
         $Param{Name} = $Article{Name};
     }
     # db quote (just not Content, use db Bind values)
-    foreach (keys %Param) {
-        $Param{$_} = $Self->{DBObject}->Quote($Param{$_}) if ($_ ne 'Content');
+    foreach (qw(Number Name Title Keywords Field1 Field2 Field3 Field4 Field5 Field6 FreeKey1 FreeText1 FreeKey2 FreeText2 FreeKey3 FreeText3 FreeKey4 FreeText4 Filename ContentType Filesize)) {
+        $Param{$_} = $Self->{DBObject}->Quote($Param{$_});
+    }
+    foreach (qw(FAQID CategoryID StateID LanguageID)) {
+        $Param{$_} = $Self->{DBObject}->Quote($Param{$_}, 'Integer');
     }
     # fill up empty stuff
     foreach my $Type (qw(Field FreeKey FreeText)) {
@@ -413,6 +423,10 @@ sub FAQDelete {
         return;
       }
     }
+    # db quote
+    foreach (qw(FAQID)) {
+        $Param{$_} = $Self->{DBObject}->Quote($Param{$_}, 'Integer');
+    }
     if ($Self->FAQHistoryDelete(%Param)) {
         if ($Self->{DBObject}->Prepare(SQL => "DELETE FROM faq_item WHERE id = $Param{FAQID}")) {
             return 1;
@@ -448,9 +462,12 @@ sub FAQHistoryAdd {
       }
     }
     # db quote
-    foreach (keys %Param) {
+    foreach (qw(Name)) {
         $Param{$_} = $Self->{DBObject}->Quote($Param{$_}) || '';
     }
+    foreach (qw(FAQID)) {
+        $Param{$_} = $Self->{DBObject}->Quote($Param{$_}, 'Integer');
+    }
     my $SQL = "INSERT INTO faq_history (name, item_id, ".
             " create_time, create_by, change_time, change_by)".
             " VALUES ".
@@ -487,8 +504,8 @@ sub FAQHistoryGet {
       }
     }
     # db quote
-    foreach (keys %Param) {
-        $Param{$_} = $Self->{DBObject}->Quote($Param{$_});
+    foreach (qw(FAQID)) {
+        $Param{$_} = $Self->{DBObject}->Quote($Param{$_}, 'Integer');
     }
     my @Data = ();
     $Self->{DBObject}->Prepare(
@@ -525,8 +542,8 @@ sub FAQHistoryDelete {
       }
     }
     # db quote
-    foreach (keys %Param) {
-        $Param{$_} = $Self->{DBObject}->Quote($Param{$_});
+    foreach (qw(FAQID)) {
+        $Param{$_} = $Self->{DBObject}->Quote($Param{$_}, 'Integer');
     }
     $Self->{DBObject}->Prepare(
         SQL => "DELETE FROM faq_history WHERE item_id = $Param{FAQID}",
@@ -622,8 +639,8 @@ sub CategoryGet {
       }
     }
     # db quote
-    foreach (keys %Param) {
-        $Param{$_} = $Self->{DBObject}->Quote($Param{$_});
+    foreach (qw(ID)) {
+        $Param{$_} = $Self->{DBObject}->Quote($Param{$_}, 'Integer');
     }
     # sql
     my %Data = ();
@@ -662,7 +679,7 @@ sub CategoryAdd {
       }
     }
     # db quote
-    foreach (keys %Param) {
+    foreach (qw(Name Comment)) {
         $Param{$_} = $Self->{DBObject}->Quote($Param{$_}) || '';
     }
     my $SQL = "INSERT INTO faq_category (name, comments, ".
@@ -719,9 +736,12 @@ sub CategoryUpdate {
       }
     }
     # db quote
-    foreach (keys %Param) {
+    foreach (qw(Name Comment)) {
         $Param{$_} = $Self->{DBObject}->Quote($Param{$_}) || '';
     }
+    foreach (qw(ID)) {
+        $Param{$_} = $Self->{DBObject}->Quote($Param{$_}, 'Integer');
+    }
     # sql
     my $SQL = "UPDATE faq_category SET name = '$Param{Name}', ".
           " comments = '$Param{Comment}', ".
@@ -841,9 +861,12 @@ sub StateUpdate {
       }
     }
     # db quote
-    foreach (keys %Param) {
+    foreach (qw(Name)) {
         $Param{$_} = $Self->{DBObject}->Quote($Param{$_}) || '';
     }
+    foreach (qw(ID TypeID)) {
+        $Param{$_} = $Self->{DBObject}->Quote($Param{$_}, 'Integer');
+    }
     # sql
     my $SQL = "UPDATE faq_state SET name = '$Param{Name}', type_id = $Param{TypeID}, ".
           " WHERE id = $Param{ID}";
@@ -878,9 +901,12 @@ sub StateAdd {
       }
     }
     # db quote
-    foreach (keys %Param) {
+    foreach (qw(Name)) {
         $Param{$_} = $Self->{DBObject}->Quote($Param{$_}) || '';
     }
+    foreach (qw(TypeID)) {
+        $Param{$_} = $Self->{DBObject}->Quote($Param{$_}, 'Integer');
+    }
     my $SQL = "INSERT INTO faq_state (name, type_id) ".
             " VALUES ".
             " ('$Param{Name}', $Param{TypeID}) ";
@@ -914,8 +940,8 @@ sub StateGet {
       }
     }
     # db quote
-    foreach (keys %Param) {
-        $Param{$_} = $Self->{DBObject}->Quote($Param{$_});
+    foreach (qw(ID)) {
+        $Param{$_} = $Self->{DBObject}->Quote($Param{$_}, 'Integer');
     }
     # sql
     my %Data = ();
@@ -981,9 +1007,12 @@ sub LanguageUpdate {
       }
     }
     # db quote
-    foreach (keys %Param) {
+    foreach (qw(Name)) {
         $Param{$_} = $Self->{DBObject}->Quote($Param{$_}) || '';
     }
+    foreach (qw(ID)) {
+        $Param{$_} = $Self->{DBObject}->Quote($Param{$_}, 'Integer');
+    }
     # sql
     my $SQL = "UPDATE faq_language SET name = '$Param{Name}' ".
           " WHERE id = $Param{ID}";
@@ -1016,7 +1045,7 @@ sub LanguageAdd {
       }
     }
     # db quote
-    foreach (keys %Param) {
+    foreach (qw(Name)) {
         $Param{$_} = $Self->{DBObject}->Quote($Param{$_}) || '';
     }
     my $SQL = "INSERT INTO faq_language (name) ".
@@ -1052,8 +1081,8 @@ sub LanguageGet {
       }
     }
     # db quote
-    foreach (keys %Param) {
-        $Param{$_} = $Self->{DBObject}->Quote($Param{$_});
+    foreach (qw(ID)) {
+        $Param{$_} = $Self->{DBObject}->Quote($Param{$_}, 'Integer');
     }
     # sql
     my %Data = ();
@@ -1078,6 +1107,7 @@ search in articles
       What => '*some text*',
       Keywords => '*webserver*',
       States = ['public', 'internal'],
+      Limit => 150,
   );
 
 =cut
@@ -1140,7 +1170,7 @@ sub FAQSearch {
     }
     $SQL .= $Ext." ORDER BY i.change_time DESC";
     my @List = ();
-    $Self->{DBObject}->Prepare(SQL => $SQL, Limit => 500);
+    $Self->{DBObject}->Prepare(SQL => $SQL, Limit => $Param{Limit} || 500);
     while  (my @Row = $Self->{DBObject}->FetchrowArray()) {
         push (@List, $Row[0]);
     }
@@ -1161,6 +1191,6 @@ did not receive this file, see http://www.gnu.org/licenses/gpl.txt.
 
 =head1 VERSION
 
-$Revision: 1.23 $ $Date: 2005/08/19 15:37:47 $
+$Revision: 1.27 $ $Date: 2005/11/05 11:59:52 $
 
 =cut
