@@ -1,11 +1,11 @@
 # --
 # Kernel/System/PostMaster/NewTicket.pm - sub part of PostMaster.pm
-# Copyright (C) 2001-2004 Martin Edenhofer <martin+code@otrs.org>
+# Copyright (C) 2001-2005 Martin Edenhofer <martin+code@otrs.org>
 # --
-# $Id: NewTicket.pm,v 1.48 2004/06/22 09:04:09 martin Exp $
+# $Id: NewTicket.pm,v 1.52 2005/02/23 10:27:01 martin Exp $
 # --
-# This software comes with ABSOLUTELY NO WARRANTY. For details, see 
-# the enclosed file COPYING for license information (GPL). If you 
+# This software comes with ABSOLUTELY NO WARRANTY. For details, see
+# the enclosed file COPYING for license information (GPL). If you
 # did not receive this file, see http://www.gnu.org/licenses/gpl.txt.
 # --
 
@@ -16,20 +16,20 @@ use Kernel::System::AutoResponse;
 use Kernel::System::CustomerUser;
 
 use vars qw($VERSION);
-$VERSION = '$Revision: 1.48 $';
+$VERSION = '$Revision: 1.52 $';
 $VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
 
 # --
 sub new {
     my $Type = shift;
     my %Param = @_;
-   
-    # allocate new hash for object 
-    my $Self = {}; 
+
+    # allocate new hash for object
+    my $Self = {};
     bless ($Self, $Type);
-   
+
     $Self->{Debug} = $Param{Debug} || 0;
- 
+
     # get all objects
     foreach (qw(DBObject ConfigObject TicketObject LogObject ParseObject QueueObject)) {
         $Self->{$_} = $Param{$_} || die 'Got no $_';
@@ -55,11 +55,11 @@ sub Run {
     my %GetParam = %{$Param{GetParam}};
     my $Comment = $Param{Comment} || '';
     my $AutoResponseType = $Param{AutoResponseType} || '';
-    # -- 
+    # --
     # get queue id and name
     # --
-    my $QueueID = $Param{QueueID} || die "need QueueID!"; 
-    my $Queue = $Self->{QueueObject}->QueueLookup(QueueID => $QueueID);    
+    my $QueueID = $Param{QueueID} || die "need QueueID!";
+    my $Queue = $Self->{QueueObject}->QueueLookup(QueueID => $QueueID);
     # --
     # get state
     # --
@@ -72,10 +72,10 @@ sub Run {
     # --
     my $Priority = $Self->{ConfigObject}->Get('PostmasterDefaultPriority') || '3 normal';
     if ($GetParam{'X-OTRS-Priority'}) {
-        $Priority = $GetParam{'X-OTRS-Priority'}; 
+        $Priority = $GetParam{'X-OTRS-Priority'};
     }
-    # --    
-    # get sender email 
+    # --
+    # get sender email
     # --
     my @EmailAddresses = $Self->{ParseObject}->SplitAddressLine(
         Line => $GetParam{From},
@@ -85,13 +85,13 @@ sub Run {
             Email => $_,
         );
     }
-    # --    
+    # --
     # get customer id (sender email) if there is no customer id given
     # --
     if (!$GetParam{'X-OTRS-CustomerNo'} && $GetParam{'X-OTRS-CustomerUser'}) {
         # get customer user data form X-OTRS-CustomerUser
         my %CustomerData = $Self->{CustomerUserObject}->CustomerUserDataGet(
-            User => $GetParam{'X-OTRS-CustomerUser'}, 
+            User => $GetParam{'X-OTRS-CustomerUser'},
         );
         if (%CustomerData) {
             $GetParam{'X-OTRS-CustomerNo'} = $CustomerData{UserCustomerID};
@@ -113,7 +113,7 @@ sub Run {
             }
             my %List = $Self->{CustomerUserObject}->CustomerSearch(
                 PostMasterSearch => lc($GetParam{'EmailForm'}),
-            ); 
+            );
             foreach (keys %List) {
                 %CustomerData = $Self->{CustomerUserObject}->CustomerUserDataGet(
                   User => $_,
@@ -125,7 +125,7 @@ sub Run {
             $GetParam{'X-OTRS-CustomerUser'} = $CustomerData{UserLogin};
             # notice that UserLogin is form customer source backend
             $Self->{LogObject}->Log(
-                Priority => 'notice', 
+                Priority => 'notice',
                 Message => "Take UserLogin ($CustomerData{UserLogin}) from ".
                    "customer source backend based on ($GetParam{'EmailForm'}).",
             );
@@ -134,7 +134,7 @@ sub Run {
             $GetParam{'X-OTRS-CustomerNo'} = $CustomerData{UserCustomerID};
             # notice that UserCustomerID is form customer source backend
             $Self->{LogObject}->Log(
-                Priority => 'notice', 
+                Priority => 'notice',
                 Message => "Take UserCustomerID ($CustomerData{UserCustomerID})".
                    " from customer source backend based on ($GetParam{'EmailForm'}).",
             );
@@ -143,27 +143,27 @@ sub Run {
     # --
     # if there is no customer id found!
     # --
-    if (!$GetParam{'X-OTRS-CustomerNo'}) { 
+    if (!$GetParam{'X-OTRS-CustomerNo'}) {
         $GetParam{'X-OTRS-CustomerNo'} = $GetParam{'SenderEmailAddress'};
     }
     # --
     # if there is no customer user found!
     # --
-    if (!$GetParam{'X-OTRS-CustomerUser'}) { 
+    if (!$GetParam{'X-OTRS-CustomerUser'}) {
         $GetParam{'X-OTRS-CustomerUser'} = $GetParam{'SenderEmailAddress'};
     }
-    # -- 
+    # --
     # create new ticket
     # --
     my $NewTn = $Self->{TicketObject}->CreateTicketNr();
-    # -- 
+    # --
     # do db insert
     # --
     my $TicketID = $Self->{TicketObject}->TicketCreate(
         TN => $NewTn,
+        Title => $GetParam{Subject},
         QueueID => $QueueID,
         Lock => 'unlock',
-        GroupID => 1,
         Priority => $Priority,
         State => $State,
         CustomerNo => $GetParam{'X-OTRS-CustomerNo'},
@@ -202,7 +202,7 @@ sub Run {
             }
         }
     }
-    # -- 
+    # --
     # do article db insert
     # --
     my $ArticleID = $Self->{TicketObject}->ArticleCreate(
@@ -234,7 +234,7 @@ sub Run {
             State => 'removed',
         );
         $Self->{LogObject}->Log(
-            Priority => 'error', 
+            Priority => 'error',
             Message => "Can't process email with MessageID <$GetParam{'Message-ID'}>! ".
               "Please create a bug report with this email (var/spool/) on http://bugs.otrs.org/!",
         );
@@ -275,34 +275,28 @@ sub Run {
             }
         }
     }
-    # --    
+    # --
     # write plain email to the storage
     # --
     $Self->{TicketObject}->ArticleWritePlain(
-        ArticleID => $ArticleID, 
+        ArticleID => $ArticleID,
         Email => $Self->{ParseObject}->GetPlainEmail(),
         UserID => $Param{InmailUserID},
     );
-    # --    
+    # --
     # write attachments to the storage
     # --
     foreach my $Attachment ($Self->{ParseObject}->GetAttachments()) {
         $Self->{TicketObject}->ArticleWriteAttachment(
-            Content => $Attachment->{Content}, 
+            Content => $Attachment->{Content},
             Filename => $Attachment->{Filename},
             ContentType => $Attachment->{ContentType},
             ArticleID => $ArticleID,
             UserID => $Param{InmailUserID},
         );
     }
-    # do log
-    $Self->{LogObject}->Log(
-	Priority => 'notice',
-        Message => "New Ticket [$NewTn] created (TicketID=$TicketID, " .
-        "ArticleID=$ArticleID). $Comment"
-    );
-    
-    return 1;
+
+    return $TicketID;
 }
 # --
 
