@@ -1,8 +1,8 @@
 # --
-# Kernel/System/Queue.pm - lib for queue funktions
-# Copyright (C) 2001-2004 Martin Edenhofer <martin+code@otrs.org>
+# Kernel/System/Queue.pm - lib for queue functions
+# Copyright (C) 2001-2005 Martin Edenhofer <martin+code@otrs.org>
 # --
-# $Id: Queue.pm,v 1.45.2.1 2004/11/04 10:45:43 martin Exp $
+# $Id: Queue.pm,v 1.57 2005/11/11 16:35:58 martin Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -17,7 +17,7 @@ use Kernel::System::Group;
 use Kernel::System::CustomerGroup;
 
 use vars qw($VERSION);
-$VERSION = '$Revision: 1.45.2.1 $';
+$VERSION = '$Revision: 1.57 $';
 $VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
 
 =head1 NAME
@@ -51,8 +51,37 @@ sub new {
 
     # lib object
     $Self->{StdResponseObject} = Kernel::System::StdResponse->new(%Param);
-    $Self->{GroupObject} = Kernel::System::Group->new(%Param);
-    $Self->{CustomerGroupObject} = Kernel::System::CustomerGroup->new(%Param);
+    if (!$Param{GroupObject}) {
+        $Self->{GroupObject} = Kernel::System::Group->new(%Param);
+    }
+    else {
+        $Self->{GroupObject} = $Param{GroupObject};
+    }
+    if (!$Param{CustomerGroupObject}) {
+        $Self->{CustomerGroupObject} = Kernel::System::CustomerGroup->new(%Param);
+    }
+    else {
+        $Self->{CustomerGroupObject} = $Param{CustomerGroupObject};
+    }
+
+    # --------------------------------------------------- #
+    #  default queue  settings                            #
+    #  these settings are used by the CLI version         #
+    # --------------------------------------------------- #
+    $Self->{QueueDefaults} = {
+        UnlockTimeout => 0,
+        EscalationTime => 0,
+        FollowUpLock => 0,
+        SystemAddressID => 1,
+        SalutationID => 1,
+        SignatureID => 1,
+        FollowUpID => 1,
+        FollowUpLock => 0,
+        MoveNotify => 0,
+        LockNotify => 0,
+        StateNotify => 0,
+    };
+
     return $Self;
 }
 
@@ -60,26 +89,33 @@ sub new {
 
 get a queue system email address as hash (Email, RealName)
 
-    my %Adresss = $Self->{QueueObject}->GetSystemAddress(QueueID => 123);
+    my %Adresss = $Self->{QueueObject}->GetSystemAddress(
+        QueueID => 123,
+    );
 
 =cut
 
 sub GetSystemAddress {
     my $Self = shift;
     my %Param = @_;
-    my %Adresss;
+    my %Address;
     my $QueueID = $Param{QueueID} || $Self->{QueueID};
     my $SQL = "SELECT sa.value0, sa.value1 FROM system_address sa, queue sq ".
 	" WHERE ".
-	" sq.id = ".$Self->{DBObject}->Quote($QueueID)." ".
+	" sq.id = ".$Self->{DBObject}->Quote($QueueID, 'Integer')." ".
 	" and ".
 	" sa.id = sq.system_address_id";
     $Self->{DBObject}->Prepare(SQL => $SQL);
-    while (my @RowTmp = $Self->{DBObject}->FetchrowArray()) {
-        $Adresss{Email} = $RowTmp[0];
-	$Adresss{RealName} = $RowTmp[1];
+    while (my @Row = $Self->{DBObject}->FetchrowArray()) {
+        $Address{Email} = $Row[0];
+        $Address{RealName} = $Row[1];
     }
-    return %Adresss;
+    # prepare realname quote
+    if ($Address{RealName} =~ /(,|@|\(|\)|:)/ && $Address{RealName} !~ /^("|')/) {
+        $Address{RealName} =~ s/"/\"/g;
+        $Address{RealName} = '"'.$Address{RealName}.'"';
+    }
+    return %Address;
 }
 
 =item GetSalutation()
@@ -99,8 +135,8 @@ sub GetSalutation {
         return;
     }
     # db quote
-    foreach (keys %Param) {
-        $Param{$_} = $Self->{DBObject}->Quote($Param{$_});
+    foreach (qw(QueueID)) {
+        $Param{$_} = $Self->{DBObject}->Quote($Param{$_}, 'Integer');
     }
     # sql
     my $String = '';
@@ -110,8 +146,8 @@ sub GetSalutation {
         " and ".
         " sq.salutation_id = sa.id";
     $Self->{DBObject}->Prepare(SQL => $SQL);
-    while (my @RowTmp = $Self->{DBObject}->FetchrowArray()) {
-        $String = $RowTmp[0];
+    while (my @Row = $Self->{DBObject}->FetchrowArray()) {
+        $String = $Row[0];
     }
     return $String;
 }
@@ -133,8 +169,8 @@ sub GetSignature {
         return;
     }
     # db quote
-    foreach (keys %Param) {
-        $Param{$_} = $Self->{DBObject}->Quote($Param{$_});
+    foreach (qw(QueueID)) {
+        $Param{$_} = $Self->{DBObject}->Quote($Param{$_}, 'Integer');
     }
     # sql
     my $String = '';
@@ -144,8 +180,8 @@ sub GetSignature {
         " and ".
         " sq.signature_id = si.id";
     $Self->{DBObject}->Prepare(SQL => $SQL);
-    while (my @RowTmp = $Self->{DBObject}->FetchrowArray()) {
-        $String = $RowTmp[0];
+    while (my @Row = $Self->{DBObject}->FetchrowArray()) {
+        $String = $Row[0];
     }
     return $String;
 }
@@ -168,8 +204,8 @@ sub GetStdResponse {
         return;
     }
     # db quote
-    foreach (keys %Param) {
-        $Param{$_} = $Self->{DBObject}->Quote($Param{$_});
+    foreach (qw(ID)) {
+        $Param{$_} = $Self->{DBObject}->Quote($Param{$_}, 'Integer');
     }
     # sql
     my $SQL = "SELECT text FROM standard_response".
@@ -259,7 +295,7 @@ sub GetStdResponses {
         " FROM ".
         " standard_response sr, queue_standard_response qsr".
         " WHERE ".
-        " qsr.queue_id in (".$Self->{DBObject}->Quote($Param{QueueID}).")".
+        " qsr.queue_id in (".$Self->{DBObject}->Quote($Param{QueueID}, 'Integer').")".
         " AND ".
         " qsr.standard_response_id = sr.id".
         " AND ".
@@ -343,7 +379,6 @@ sub GetAllQueues {
     }
     return %MoveQueues;
 }
-# --
 
 =item GetAllCustomQueues()
 
@@ -362,8 +397,8 @@ sub GetAllCustomQueues {
         return;
     }
     # db quote
-    foreach (keys %Param) {
-        $Param{$_} = $Self->{DBObject}->Quote($Param{$_});
+    foreach (qw(UserID)) {
+        $Param{$_} = $Self->{DBObject}->Quote($Param{$_}, 'Integer');
     }
     # fetch all queues
     my @QueueIDs;
@@ -377,9 +412,11 @@ sub GetAllCustomQueues {
 
 =item QueueLookup()
 
-...
+get id or name for queue
 
-    ...
+    my $Queue = $QueueObject->QueueLookup(QueueID => $QueueID);
+
+    my $QueueID = $QueueObject->QueueLookup(Queue => $Queue);
 
 =cut
 
@@ -409,7 +446,7 @@ sub QueueLookup {
     else {
         $Param{What} = $Param{QueueID};
         $Suffix = 'Queue';
-        $SQL = "SELECT name FROM queue WHERE id = ".$Self->{DBObject}->Quote($Param{QueueID})."";
+        $SQL = "SELECT name FROM queue WHERE id = ".$Self->{DBObject}->Quote($Param{QueueID}, 'Integer')."";
     }
     $Self->{DBObject}->Prepare(SQL => $SQL);
     while (my @Row = $Self->{DBObject}->FetchrowArray()) {
@@ -445,8 +482,8 @@ sub GetFollowUpOption {
         return;
     }
     # db quote
-    foreach (keys %Param) {
-        $Param{$_} = $Self->{DBObject}->Quote($Param{$_});
+    foreach (qw(QueueID)) {
+        $Param{$_} = $Self->{DBObject}->Quote($Param{$_}, 'Integer');
     }
     # fetch queues data
     my $Return = '';
@@ -481,8 +518,8 @@ sub GetFollowUpLockOption {
         return;
     }
     # db quote
-    foreach (keys %Param) {
-        $Param{$_} = $Self->{DBObject}->Quote($Param{$_});
+    foreach (qw(QueueID)) {
+        $Param{$_} = $Self->{DBObject}->Quote($Param{$_}, 'Integer');
     }
     # fetch queues data
     my $Return = 0;
@@ -492,8 +529,8 @@ sub GetFollowUpLockOption {
         " WHERE ".
         " sq.id = $Param{QueueID}";
     $Self->{DBObject}->Prepare(SQL => $SQL);
-    while (my @RowTmp = $Self->{DBObject}->FetchrowArray()) {
-        $Return = $RowTmp[0];
+    while (my @Row = $Self->{DBObject}->FetchrowArray()) {
+        $Return = $Row[0];
     }
     return $Return;
 }
@@ -515,8 +552,8 @@ sub GetQueueGroupID {
         return;
     }
     # db quote
-    foreach (keys %Param) {
-        $Param{$_} = $Self->{DBObject}->Quote($Param{$_});
+    foreach (qw(QueueID)) {
+        $Param{$_} = $Self->{DBObject}->Quote($Param{$_}, 'Integer');
     }
     # sql
     my $GID = '';
@@ -534,9 +571,21 @@ sub GetQueueGroupID {
 
 =item QueueAdd()
 
-...
+add queue with attributes
 
-    ...
+    $QueueObject->QueueAdd(
+        Name            => 'Some::Queue',
+        ValidID         => 1,
+        GroupID         => 1,
+        SystemAddressID => 1,
+        SalutationID    => 1,
+        SignatureID     => 1,
+        UserID          => 123,
+        MoveNotify      => 0,
+        StateNotify     => 0,
+        LockNotify      => 0,
+        OwnerNotify     => 0,
+    );
 
 =cut
 
@@ -574,19 +623,14 @@ sub QueueAdd {
        ValidID
    );
 
-
-   foreach (@Params) {
-       $Param{$_} = $Self->{DBObject}->Quote($Param{$_});
-   };
-
    for (qw(UnlockTimeout EscalationTime FollowUpLock SystemAddressID SalutationID SignatureID FollowUpID FollowUpLock MoveNotify StateNotify LockNotify OwnerNotify DefaultSignKey)) {
       # these are coming from Config.pm
       # I added default values in the Load Routine
-      $Param{$_} = $Self->{ConfigObject}{QueueDefaults}{$_} || 0  unless ($Param{$_});
+      $Param{$_} = $Self->{QueueDefaults}{$_} || 0  unless ($Param{$_});
    };
 
    # check needed stuff
-   foreach (qw(Name GroupID SystemAddressID SalutationID SignatureID MoveNotify StateNotify LockNotify OwnerNotify ValidID)) {
+   foreach (qw(Name GroupID SystemAddressID SalutationID SignatureID MoveNotify StateNotify LockNotify OwnerNotify ValidID UserID)) {
       if (!defined($Param{$_})) {
         $Self->{LogObject}->Log(Priority => 'error', Message => "Need $_!");
         return;
@@ -606,6 +650,13 @@ sub QueueAdd {
         );
         return;
     }
+    # quote db
+    foreach (qw(Name DefaultSignKey Comment)) {
+        $Param{$_} = $Self->{DBObject}->Quote($Param{$_}) || '';
+    };
+    foreach (qw(GroupID UnlockTimeout SystemAddressID SalutationID SignatureID FollowUpID FollowUpLock EscalationTime MoveNotify StateNotify ValidID)) {
+        $Param{$_} = $Self->{DBObject}->Quote($Param{$_}, 'Integer');
+    }
     my $SQL = "INSERT INTO queue ".
        "(name, ".
        " group_id, ".
@@ -649,53 +700,59 @@ sub QueueAdd {
        " current_timestamp, ".
        " $Param{UserID})";
 
-   if ($Self->{DBObject}->Do(SQL => $SQL)) {
-      # get new queue id
-      $SQL = "SELECT id ".
-       " FROM ".
-       " queue ".
-       " WHERE ".
-       " name = '$Param{Name}'";
-      my $QueueID = '';
-      $Self->{DBObject}->Prepare(SQL => $SQL);
-      while (my @RowTmp = $Self->{DBObject}->FetchrowArray()) {
-         $QueueID = $RowTmp[0];
-      }
-      # add default responses (if needed), add response by name
-      if ($Self->{ConfigObject}->Get('StdResponse2QueueByCreating')) {
-          foreach (@{$Self->{ConfigObject}->{StdResponse2QueueByCreating}}) {
-              my $StdResponseID = $Self->{StdResponseObject}->StdResponseLookup(StdResponse => $_);
-              if ($StdResponseID) {
+    if ($Self->{DBObject}->Do(SQL => $SQL)) {
+        # get new queue id
+        $SQL = "SELECT id ".
+            " FROM ".
+            " queue ".
+            " WHERE ".
+            " name = '$Param{Name}'";
+        my $QueueID = '';
+        $Self->{DBObject}->Prepare(SQL => $SQL);
+        while (my @Row = $Self->{DBObject}->FetchrowArray()) {
+            $QueueID = $Row[0];
+        }
+        # add default responses (if needed), add response by name
+        if ($Self->{ConfigObject}->Get('StdResponse2QueueByCreating')) {
+            foreach (@{$Self->{ConfigObject}->{StdResponse2QueueByCreating}}) {
+                my $StdResponseID = $Self->{StdResponseObject}->StdResponseLookup(StdResponse => $_);
+                if ($StdResponseID) {
+                    $Self->SetQueueStdResponse(
+                        QueueID => $QueueID,
+                        ResponseID => $StdResponseID,
+                        UserID => $Param{UserID},
+                    );
+                }
+            }
+        }
+        # add response by id
+        if ($Self->{ConfigObject}->Get('StdResponseID2QueueByCreating')) {
+            foreach (@{$Self->{ConfigObject}->{StdResponseID2QueueByCreating}}) {
                 $Self->SetQueueStdResponse(
-                  QueueID => $QueueID,
-                  ResponseID => $StdResponseID,
-                  UserID => $Param{UserID},
+                    QueueID => $QueueID,
+                    ResponseID => $_,
+                    UserID => $Param{UserID},
                 );
-              }
-          }
-      }
-      # add response by id
-      if ($Self->{ConfigObject}->Get('StdResponseID2QueueByCreating')) {
-          foreach (@{$Self->{ConfigObject}->{StdResponseID2QueueByCreating}}) {
-              $Self->SetQueueStdResponse(
-                  QueueID => $QueueID,
-                  ResponseID => $_,
-                  UserID => $Param{UserID},
-              );
-          }
-      }
-      return $QueueID;
+            }
+        }
+        return $QueueID;
    }
    else {
-      return;
+        return;
    }
 }
 
 =item QueueGet()
 
-...
+get queue attributes
 
-    ...
+    my %Queue = $QueueObject->QueueGet(
+        ID => 123,
+    );
+
+    my %Queue = $QueueObject->QueueGet(
+        Name => 'Some::Queue',
+    );
 
 =cut
 
@@ -728,7 +785,7 @@ sub QueueGet {
     if ($Param{ID}) {
         $Param{What} = $Param{ID};
         $Suffix = 'ID';
-        $SQL .= " q.id = ".$Self->{DBObject}->Quote($Param{ID})."";
+        $SQL .= " q.id = ".$Self->{DBObject}->Quote($Param{ID}, 'Integer')."";
     }
     else {
         $Param{What} = $Param{Name};
@@ -775,9 +832,22 @@ sub QueueGet {
 
 =item QueueUpdate()
 
-...
+update queue attributes
 
-    ...
+    $QueueObject->QueueUpdate(
+        QueueID         => 123,
+        Name            => 'Some::Queue',
+        ValidID         => 1,
+        GroupID         => 1,
+        SystemAddressID => 1,
+        SalutationID    => 1,
+        SignatureID     => 1,
+        UserID          => 123,
+        MoveNotify      => 0,
+        StateNotify     => 0,
+        LockNotify      => 0,
+        OwnerNotify     => 0,
+    );
 
 =cut
 
@@ -799,12 +869,15 @@ sub QueueUpdate {
     }
     # db quote
     my %DB = ();
-    foreach (keys %Param) {
-        $DB{$_} = $Self->{DBObject}->Quote($Param{$_}) || '';
-    }
     # check !!!
-    foreach (qw(UnlockTimeout EscalationTime FollowUpLock MoveNotify StateNotify LockNotify OwnerNotify DefaultSignKey)) {
-        $DB{$_} = 0 if (!$Param{$_});
+    foreach (qw(UnlockTimeout EscalationTime FollowUpLock MoveNotify StateNotify LockNotify OwnerNotify FollowUpID FollowUpLock DefaultSignKey)) {
+        $Param{$_} = 0 if (!$Param{$_});
+    }
+    foreach (qw(Name DefaultSignKey Comment)) {
+        $DB{$_} = $Self->{DBObject}->Quote($Param{$_}) || '';
+    };
+    foreach (qw(QueueID GroupID UnlockTimeout SystemAddressID SalutationID SignatureID FollowUpID FollowUpLock EscalationTime StateNotify LockNotify OwnerNotify MoveNotify StateNotify ValidID UserID)) {
+        $DB{$_} = $Self->{DBObject}->Quote($Param{$_}, 'Integer');
     }
     # check queue name
     if ($Param{Name} =~ /::$/i) {
@@ -878,7 +951,6 @@ sub QueueUpdate {
         return;
     }
 }
-# --
 1;
 
 =head1 TERMS AND CONDITIONS
@@ -893,6 +965,6 @@ did not receive this file, see http://www.gnu.org/licenses/gpl.txt.
 
 =head1 VERSION
 
-$Revision: 1.45.2.1 $ $Date: 2004/11/04 10:45:43 $
+$Revision: 1.57 $ $Date: 2005/11/11 16:35:58 $
 
 =cut
