@@ -1,8 +1,8 @@
 # --
 # Kernel/System/Ticket/Article.pm - global article module for OTRS kernel
-# Copyright (C) 2001-2006 Martin Edenhofer <martin+code@otrs.org>
+# Copyright (C) 2001-2005 Martin Edenhofer <martin+code@otrs.org>
 # --
-# $Id: Article.pm,v 1.94.2.8 2006/06/22 15:02:45 cs Exp $
+# $Id: Article.pm,v 1.94 2005/10/31 10:07:03 martin Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -18,7 +18,7 @@ use Mail::Internet;
 use Kernel::System::StdAttachment;
 
 use vars qw($VERSION);
-$VERSION = '$Revision: 1.94.2.8 $';
+$VERSION = '$Revision: 1.94 $';
 $VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
 
 =head1 NAME
@@ -85,9 +85,9 @@ sub ArticleCreate {
         return;
       }
     }
-    # add 'no body!' if there is no body there!
+    # add 'no body found!' if there is no body there!
     if (!$Param{Body}) {
-        $Param{Body} = 'No body';
+        $Param{Body} = 'no body found!';
     }
     # if body isn't text, attach body as attachment (mostly done by OE) :-/
     elsif ($Param{ContentType} && $Param{ContentType} !~ /\btext\b/i) {
@@ -1432,7 +1432,7 @@ sub SendAgentNotification {
         return;
       }
     }
-    # compat Type
+    # comapt Type
     if ($Param{Type} =~/(EmailAgent|EmailCustomer|PhoneCallCustomer|WebRequestCustomer|SystemRequest)/) {
         $Param{Type} = 'NewTicket';
     }
@@ -1557,15 +1557,10 @@ sub SendAgentNotification {
     $Notification{Body} =~ s/<OTRS_CUSTOMER_DATA_.+?>/-/gi;
     $Notification{Subject} =~ s/<OTRS_CUSTOMER_DATA_.+?>/-/gi;
 
-    # Replace empty subject with single space because tag was inserted into notification
-    if (!$GetParam{Subject}) {
-        $GetParam{Subject} = "No subject";
-    }
-
     foreach (keys %GetParam) {
         if ($GetParam{$_}) {
             $Notification{Body} =~ s/<OTRS_CUSTOMER_$_>/$GetParam{$_}/gi;
-            $Notification{Subject} =~ s/<OTRS_CUSTOMER_$_>/$GetParam{$_}/gii;
+            $Notification{Subject} =~ s/<OTRS_CUSTOMER_$_>/$GetParam{$_}/gi;
         }
     }
     if ($Notification{Body} =~ /<OTRS_CUSTOMER_EMAIL\[(.+?)\]>/g) {
@@ -1928,24 +1923,9 @@ sub SendAutoResponse {
             $Param{Body} =~ s/<OTRS_CUSTOMER_$_>/$GetParam{$_}/gi;
         }
     }
-    # ticket data
-    my %Ticket = $Self->TicketGet(TicketID => $Param{TicketID});
-    foreach (keys %Ticket) {
-        if (defined($Ticket{$_})) {
-            $Param{Body} =~ s/<OTRS_TICKET_$_>/$Ticket{$_}/gi;
-            $Param{Subject} =~ s/<OTRS_TICKET_$_>/$Ticket{$_}/gi;
-        }
-    }
     # replace some special stuff
     $Param{Body} =~ s/<OTRS_TICKET_NUMBER>/$Article{TicketNumber}/gi;
     $Param{Body} =~ s/<OTRS_TICKET_ID>/$Param{TicketID}/gi;
-    # cleanup
-    $Param{Subject} =~ s/<OTRS_TICKET_.+?>/-/gi;
-    $Param{Body} =~ s/<OTRS_TICKET_.+?>/-/gi;
-
-    # replace config options
-    $Param{Body} =~ s{<OTRS_CONFIG_(.+?)>}{$Self->{ConfigObject}->Get($1)}egx;
-    $Param{Subject} =~ s{<OTRS_CONFIG_(.+?)>}{$Self->{ConfigObject}->Get($1)}egx;
     # prepare customer realname
     if ($Param{Body} =~ /<OTRS_CUSTOMER_REALNAME>/) {
         # get realname
@@ -2181,34 +2161,6 @@ sub ArticleAccountedTimeGet {
     return $AccountedTime;
 }
 
-=item ArticleAccountedTimeDelete()
-
-delete accounted time of article
-
-  $TicketObject->ArticleAccountedTimeDelete(
-    ArticleID => $ArticleID,
-  );
-
-=cut
-
-sub ArticleAccountedTimeDelete {
-    my $Self = shift;
-    my %Param = @_;
-    # check needed stuff
-    if (!$Param{ArticleID}) {
-      $Self->{LogObject}->Log(Priority => 'error', Message => "Need ArticleID!");
-      return;
-    }
-    # db quote
-    foreach (qw(ArticleID UserID)) {
-        $Param{$_} = $Self->{DBObject}->Quote($Param{$_}, 'Integer');
-    }
-    # db query
-    my $SQL = "DELETE FROM time_accounting " .
-        " WHERE " .
-        " article_id = $Param{ArticleID}";
-    return $Self->{DBObject}->Do(SQL => $SQL);
-}
 
 # --
 # the following is the pod for Kernel/System/Ticket/ArticleStorage*.pm
