@@ -2,9 +2,15 @@
 -- initial_insert.sql - provides initial system data
 -- Copyright (C) 2001-2003 Martin Edenhofer <martin+code@otrs.org>
 -- --
--- $Id: initial_insert.sql,v 1.40 2005/09/24 16:48:21 martin Exp $
+-- $Id: initial_insert.sql,v 1.42 2005/10/30 12:29:12 martin Exp $
 --
 -- $Log: initial_insert.sql,v $
+-- Revision 1.42  2005/10/30 12:29:12  martin
+-- removed not needed german default salutation and signature
+--
+-- Revision 1.41  2005/10/30 09:47:37  martin
+-- added spaces for oracle init
+--
 -- Revision 1.40  2005/09/24 16:48:21  martin
 -- moved to german "Sie" form in notifcations
 --
@@ -378,35 +384,22 @@ INSERT INTO salutation
 
 Thank you for your request.
 ', 'std. salutation', 1, 1, current_timestamp, 1, current_timestamp);
-INSERT INTO salutation
-    (name, text, comments, valid_id, create_by, create_time, change_by, change_time)
-    VALUES
-    ('system standard salutation (de/buiss)', 'Sehr geehrter <OTRS_CUSTOMER_REALNAME>,
-
-Danke fuer Ihre Anfrage.
-', 'std. salutation', 1, 1, current_timestamp, 1, current_timestamp);
 
 -- signature
 INSERT INTO signature
     (name, text, comments, valid_id, create_by, create_time, change_by, change_time)
     VALUES
     ('system standard signature (en)', '
-Your OTRS-Team
+Your Ticket-Team
 
  -
  <OTRS_FIRST_NAME> <OTRS_LAST_NAME> 
---
-', 'std signature', 1, 1, current_timestamp, 1, current_timestamp);
-INSERT INTO signature
-    (name, text, comments, valid_id, create_by, create_time, change_by, change_time)
-    VALUES
-    ('system standard signature (de/buiss)', '
-Ihr OTRS Team
 
--- 
-  <OTRS_FIRST_NAME> <OTRS_LAST_NAME> 
 --
-', 'std. signature', 1, 1, current_timestamp, 1, current_timestamp);
+ Super Support - Waterford Business Park
+ 5201 Blue Lagoon Drive - 8th Floor & 9th Floor - Miami, 33126 USA
+ Email: hot@example.com - Web: http://www.example.com/
+--', 'std signature', 1, 1, current_timestamp, 1, current_timestamp);
 
 -- system_address
 INSERT INTO system_address
@@ -813,6 +806,7 @@ there is a new ticket in "<OTRS_TICKET_QUEUE>"!
 <OTRS_CONFIG_HttpType>://<OTRS_CONFIG_FQDN>/<OTRS_CONFIG_ScriptAlias>index.pl?Action=AgentZoom&TicketID=<OTRS_TICKET_TicketID>
 
 Your OTRS Notification Master', current_timestamp, 1, current_timestamp, 1);
+
 INSERT INTO notifications
   (notification_type, notification_charset, notification_language, subject, text, create_time, create_by, change_time, change_by)
   VALUES
@@ -828,6 +822,7 @@ you got a follow up!
 <OTRS_CONFIG_HttpType>://<OTRS_CONFIG_FQDN>/<OTRS_CONFIG_ScriptAlias>index.pl?Action=AgentZoom&TicketID=<OTRS_TICKET_TicketID>
 
 Your OTRS Notification Master', current_timestamp, 1, current_timestamp, 1);
+
 INSERT INTO notifications
   (notification_type, notification_charset, notification_language, subject, text, create_time, create_by, change_time, change_by)
   VALUES
@@ -843,6 +838,7 @@ unlocked (lock timeout) your locked ticket [<OTRS_TICKET_TicketNumber>].
  <OTRS_CONFIG_HttpType>://<OTRS_CONFIG_FQDN>/<OTRS_CONFIG_ScriptAlias>index.pl?Action=AgentZoom&TicketID=<OTRS_TICKET_TicketID>
 
 Your OTRS Notification Master', current_timestamp, 1, current_timestamp, 1);
+
 INSERT INTO notifications
   (notification_type, notification_charset, notification_language, subject, text, create_time, create_by, change_time, change_by)
   VALUES
@@ -856,6 +852,7 @@ Comment:
 <OTRS_CONFIG_HttpType>://<OTRS_CONFIG_FQDN>/<OTRS_CONFIG_ScriptAlias>index.pl?Action=AgentZoom&TicketID=<OTRS_TICKET_TicketID>
 
 Your OTRS Notification Master', current_timestamp, 1, current_timestamp, 1);
+
 INSERT INTO notifications
   (notification_type, notification_charset, notification_language, subject, text, create_time, create_by, change_time, change_by)
   VALUES
@@ -869,6 +866,7 @@ Note:
 <OTRS_CONFIG_HttpType>://<OTRS_CONFIG_FQDN>/<OTRS_CONFIG_ScriptAlias>index.pl?Action=AgentZoom&TicketID=<OTRS_TICKET_TicketID>
 
 Your OTRS Notification Master', current_timestamp, 1, current_timestamp, 1);
+
 INSERT INTO notifications
   (notification_type, notification_charset, notification_language, subject, text, create_time, create_by, change_time, change_by)
   VALUES
@@ -883,6 +881,7 @@ INSERT INTO notifications
 <OTRS_CONFIG_HttpType>://<OTRS_CONFIG_FQDN>/<OTRS_CONFIG_ScriptAlias>index.pl?Action=AgentZoom&TicketID=<OTRS_TICKET_TicketID>
 
 Your OTRS Notification Master', current_timestamp, 1, current_timestamp, 1);
+
 INSERT INTO notifications
   (notification_type, notification_charset, notification_language, subject, text, create_time, create_by, change_time, change_by)
   VALUES
@@ -900,6 +899,7 @@ Please have a look at:
 <OTRS_CONFIG_HttpType>://<OTRS_CONFIG_FQDN>/<OTRS_CONFIG_ScriptAlias>index.pl?Action=AgentZoom&TicketID=<OTRS_TICKET_TicketID>
 
 Your OTRS Notification Master', current_timestamp, 1, current_timestamp, 1);
+
 INSERT INTO notifications
   (notification_type, notification_charset, notification_language, subject, text, create_time, create_by, change_time, change_by)
   VALUES
@@ -950,6 +950,7 @@ Sie haben eine Nachfrage bekommen!
 <OTRS_CONFIG_HttpType>://<OTRS_CONFIG_FQDN>/<OTRS_CONFIG_ScriptAlias>index.pl?Action=AgentZoom&TicketID=<OTRS_TICKET_TicketID>
 
 Ihr OTRS Benachrichtigungs-Master', current_timestamp, 1, current_timestamp, 1);
+
 INSERT INTO notifications
   (notification_type, notification_charset, notification_language, subject, text, create_time, create_by, change_time, change_by)
   VALUES
@@ -965,6 +966,7 @@ Aufhebung der Sperre auf Dein gesperrtes Ticket [<OTRS_TICKET_TicketNumber>].
  <OTRS_CONFIG_HttpType>://<OTRS_CONFIG_FQDN>/<OTRS_CONFIG_ScriptAlias>index.pl?Action=AgentZoom&TicketID=<OTRS_TICKET_TicketID>
 
 Ihr OTRS Benachrichtigungs-Master', current_timestamp, 1, current_timestamp, 1);
+
 INSERT INTO notifications
   (notification_type, notification_charset, notification_language, subject, text, create_time, create_by, change_time, change_by)
   VALUES
@@ -978,6 +980,7 @@ Kommentar:
 <OTRS_CONFIG_HttpType>://<OTRS_CONFIG_FQDN>/<OTRS_CONFIG_ScriptAlias>index.pl?Action=AgentZoom&TicketID=<OTRS_TICKET_TicketID>
 
 Ihr OTRS Benachrichtigungs-Master', current_timestamp, 1, current_timestamp, 1);
+
 INSERT INTO notifications
   (notification_type, notification_charset, notification_language, subject, text, create_time, create_by, change_time, change_by)
   VALUES
@@ -991,6 +994,7 @@ Notiz:
 <OTRS_CONFIG_HttpType>://<OTRS_CONFIG_FQDN>/<OTRS_CONFIG_ScriptAlias>index.pl?Action=AgentZoom&TicketID=<OTRS_TICKET_TicketID>
 
 Ihr OTRS Benachrichtigungs-Master', current_timestamp, 1, current_timestamp, 1);
+
 INSERT INTO notifications
   (notification_type, notification_charset, notification_language, subject, text, create_time, create_by, change_time, change_by)
   VALUES
@@ -1005,6 +1009,7 @@ INSERT INTO notifications
 <OTRS_CONFIG_HttpType>://<OTRS_CONFIG_FQDN>/<OTRS_CONFIG_ScriptAlias>index.pl?Action=AgentZoom&TicketID=<OTRS_TICKET_TicketID>
 
 Ihr OTRS Benachrichtigungs-Master', current_timestamp, 1, current_timestamp, 1);
+
 INSERT INTO notifications
   (notification_type, notification_charset, notification_language, subject, text, create_time, create_by, change_time, change_by)
   VALUES
@@ -1022,6 +1027,7 @@ Bitte um weitere Bearbeitung:
 <OTRS_CONFIG_HttpType>://<OTRS_CONFIG_FQDN>/<OTRS_CONFIG_ScriptAlias>index.pl?Action=AgentZoom&TicketID=<OTRS_TICKET_TicketID>
 
 Ihr OTRS Benachrichtigungs-Master', current_timestamp, 1, current_timestamp, 1);
+
 INSERT INTO notifications
   (notification_type, notification_charset, notification_language, subject, text, create_time, create_by, change_time, change_by)
   VALUES
