@@ -1,13 +1,13 @@
 -- ----------------------------------------------------------
---  database: oracle, generated: Wed Sep 21 17:55:46 2005
+--  database: oracle, generated: Sun Oct 30 10:41:25 2005
 -- ----------------------------------------------------------
 ALTER TABLE valid ADD CONSTRAINT fk_valid_create_by_id FOREIGN KEY (create_by) REFERENCES system_user(id);
 ALTER TABLE valid ADD CONSTRAINT fk_valid_change_by_id FOREIGN KEY (change_by) REFERENCES system_user(id);
-ALTER TABLE ticket_priority ADD CONSTRAINT fk_ticket_priority_create_by_id FOREIGN KEY (create_by) REFERENCES system_user(id);
-ALTER TABLE ticket_priority ADD CONSTRAINT fk_ticket_priority_change_by_id FOREIGN KEY (change_by) REFERENCES system_user(id);
-ALTER TABLE ticket_lock_type ADD CONSTRAINT fk_ticket_lock_type_create_by_id FOREIGN KEY (create_by) REFERENCES system_user(id);
-ALTER TABLE ticket_lock_type ADD CONSTRAINT fk_ticket_lock_type_change_by_id FOREIGN KEY (change_by) REFERENCES system_user(id);
-ALTER TABLE ticket_lock_type ADD CONSTRAINT fk_ticket_lock_type_valid_id_id FOREIGN KEY (valid_id) REFERENCES valid(id);
+ALTER TABLE ticket_priority ADD CONSTRAINT fk_ticket_priority_create_by87 FOREIGN KEY (create_by) REFERENCES system_user(id);
+ALTER TABLE ticket_priority ADD CONSTRAINT fk_ticket_priority_change_by89 FOREIGN KEY (change_by) REFERENCES system_user(id);
+ALTER TABLE ticket_lock_type ADD CONSTRAINT fk_ticket_lock_type_create_b67 FOREIGN KEY (create_by) REFERENCES system_user(id);
+ALTER TABLE ticket_lock_type ADD CONSTRAINT fk_ticket_lock_type_change_b47 FOREIGN KEY (change_by) REFERENCES system_user(id);
+ALTER TABLE ticket_lock_type ADD CONSTRAINT fk_ticket_lock_type_valid_id26 FOREIGN KEY (valid_id) REFERENCES valid(id);
 ALTER TABLE system_user ADD CONSTRAINT fk_system_user_create_by_id FOREIGN KEY (create_by) REFERENCES system_user(id);
 ALTER TABLE system_user ADD CONSTRAINT fk_system_user_change_by_id FOREIGN KEY (change_by) REFERENCES system_user(id);
 ALTER TABLE system_user ADD CONSTRAINT fk_system_user_valid_id_id FOREIGN KEY (valid_id) REFERENCES valid(id);
@@ -23,9 +23,9 @@ ALTER TABLE group_role ADD CONSTRAINT fk_group_role_role_id_id FOREIGN KEY (role
 ALTER TABLE group_role ADD CONSTRAINT fk_group_role_group_id_id FOREIGN KEY (group_id) REFERENCES groups(id);
 ALTER TABLE group_role ADD CONSTRAINT fk_group_role_create_by_id FOREIGN KEY (create_by) REFERENCES system_user(id);
 ALTER TABLE group_role ADD CONSTRAINT fk_group_role_change_by_id FOREIGN KEY (change_by) REFERENCES system_user(id);
-ALTER TABLE group_customer_user ADD CONSTRAINT fk_group_customer_user_group_id_id FOREIGN KEY (group_id) REFERENCES groups(id);
-ALTER TABLE group_customer_user ADD CONSTRAINT fk_group_customer_user_create_by_id FOREIGN KEY (create_by) REFERENCES system_user(id);
-ALTER TABLE group_customer_user ADD CONSTRAINT fk_group_customer_user_change_by_id FOREIGN KEY (change_by) REFERENCES system_user(id);
+ALTER TABLE group_customer_user ADD CONSTRAINT fk_group_customer_user_group36 FOREIGN KEY (group_id) REFERENCES groups(id);
+ALTER TABLE group_customer_user ADD CONSTRAINT fk_group_customer_user_creat62 FOREIGN KEY (create_by) REFERENCES system_user(id);
+ALTER TABLE group_customer_user ADD CONSTRAINT fk_group_customer_user_chang92 FOREIGN KEY (change_by) REFERENCES system_user(id);
 ALTER TABLE roles ADD CONSTRAINT fk_roles_create_by_id FOREIGN KEY (create_by) REFERENCES system_user(id);
 ALTER TABLE roles ADD CONSTRAINT fk_roles_change_by_id FOREIGN KEY (change_by) REFERENCES system_user(id);
 ALTER TABLE roles ADD CONSTRAINT fk_roles_valid_id_id FOREIGN KEY (valid_id) REFERENCES valid(id);
@@ -41,8 +41,8 @@ ALTER TABLE ticket_state ADD CONSTRAINT fk_ticket_state_type_id_id FOREIGN KEY (
 ALTER TABLE ticket_state ADD CONSTRAINT fk_ticket_state_create_by_id FOREIGN KEY (create_by) REFERENCES system_user(id);
 ALTER TABLE ticket_state ADD CONSTRAINT fk_ticket_state_change_by_id FOREIGN KEY (change_by) REFERENCES system_user(id);
 ALTER TABLE ticket_state ADD CONSTRAINT fk_ticket_state_valid_id_id FOREIGN KEY (valid_id) REFERENCES valid(id);
-ALTER TABLE ticket_state_type ADD CONSTRAINT fk_ticket_state_type_create_by_id FOREIGN KEY (create_by) REFERENCES system_user(id);
-ALTER TABLE ticket_state_type ADD CONSTRAINT fk_ticket_state_type_change_by_id FOREIGN KEY (change_by) REFERENCES system_user(id);
+ALTER TABLE ticket_state_type ADD CONSTRAINT fk_ticket_state_type_create_6 FOREIGN KEY (create_by) REFERENCES system_user(id);
+ALTER TABLE ticket_state_type ADD CONSTRAINT fk_ticket_state_type_change_98 FOREIGN KEY (change_by) REFERENCES system_user(id);
 ALTER TABLE salutation ADD CONSTRAINT fk_salutation_create_by_id FOREIGN KEY (create_by) REFERENCES system_user(id);
 ALTER TABLE salutation ADD CONSTRAINT fk_salutation_change_by_id FOREIGN KEY (change_by) REFERENCES system_user(id);
 ALTER TABLE salutation ADD CONSTRAINT fk_salutation_valid_id_id FOREIGN KEY (valid_id) REFERENCES valid(id);
@@ -52,9 +52,9 @@ ALTER TABLE signature ADD CONSTRAINT fk_signature_valid_id_id FOREIGN KEY (valid
 ALTER TABLE system_address ADD CONSTRAINT fk_system_address_create_by_id FOREIGN KEY (create_by) REFERENCES system_user(id);
 ALTER TABLE system_address ADD CONSTRAINT fk_system_address_change_by_id FOREIGN KEY (change_by) REFERENCES system_user(id);
 ALTER TABLE system_address ADD CONSTRAINT fk_system_address_valid_id_id FOREIGN KEY (valid_id) REFERENCES valid(id);
-ALTER TABLE follow_up_possible ADD CONSTRAINT fk_follow_up_possible_create_by_id FOREIGN KEY (create_by) REFERENCES system_user(id);
-ALTER TABLE follow_up_possible ADD CONSTRAINT fk_follow_up_possible_change_by_id FOREIGN KEY (change_by) REFERENCES system_user(id);
-ALTER TABLE follow_up_possible ADD CONSTRAINT fk_follow_up_possible_valid_id_id FOREIGN KEY (valid_id) REFERENCES valid(id);
+ALTER TABLE follow_up_possible ADD CONSTRAINT fk_follow_up_possible_create61 FOREIGN KEY (create_by) REFERENCES system_user(id);
+ALTER TABLE follow_up_possible ADD CONSTRAINT fk_follow_up_possible_change95 FOREIGN KEY (change_by) REFERENCES system_user(id);
+ALTER TABLE follow_up_possible ADD CONSTRAINT fk_follow_up_possible_valid_45 FOREIGN KEY (valid_id) REFERENCES valid(id);
 ALTER TABLE queue ADD CONSTRAINT fk_queue_salutation_id_id FOREIGN KEY (salutation_id) REFERENCES salutation(id);
 ALTER TABLE queue ADD CONSTRAINT fk_queue_signature_id_id FOREIGN KEY (signature_id) REFERENCES signature(id);
 ALTER TABLE queue ADD CONSTRAINT fk_queue_group_id_id FOREIGN KEY (group_id) REFERENCES groups(id);
@@ -65,33 +65,33 @@ ALTER TABLE queue ADD CONSTRAINT fk_queue_change_by_id FOREIGN KEY (change_by) R
 ALTER TABLE queue ADD CONSTRAINT fk_queue_valid_id_id FOREIGN KEY (valid_id) REFERENCES valid(id);
 ALTER TABLE ticket ADD CONSTRAINT fk_ticket_ticket_lock_id_id FOREIGN KEY (ticket_lock_id) REFERENCES ticket_lock_type(id);
 ALTER TABLE ticket ADD CONSTRAINT fk_ticket_ticket_state_id_id FOREIGN KEY (ticket_state_id) REFERENCES ticket_state(id);
-ALTER TABLE ticket ADD CONSTRAINT fk_ticket_ticket_priority_id_id FOREIGN KEY (ticket_priority_id) REFERENCES ticket_priority(id);
+ALTER TABLE ticket ADD CONSTRAINT fk_ticket_ticket_priority_id67 FOREIGN KEY (ticket_priority_id) REFERENCES ticket_priority(id);
 ALTER TABLE ticket ADD CONSTRAINT fk_ticket_queue_id_id FOREIGN KEY (queue_id) REFERENCES queue(id);
 ALTER TABLE ticket ADD CONSTRAINT fk_ticket_create_by_id FOREIGN KEY (create_by) REFERENCES system_user(id);
 ALTER TABLE ticket ADD CONSTRAINT fk_ticket_change_by_id FOREIGN KEY (change_by) REFERENCES system_user(id);
 ALTER TABLE ticket ADD CONSTRAINT fk_ticket_user_id_id FOREIGN KEY (user_id) REFERENCES system_user(id);
 ALTER TABLE ticket ADD CONSTRAINT fk_ticket_valid_id_id FOREIGN KEY (valid_id) REFERENCES valid(id);
-ALTER TABLE ticket_history ADD CONSTRAINT fk_ticket_history_priority_id_id FOREIGN KEY (priority_id) REFERENCES ticket_priority(id);
+ALTER TABLE ticket_history ADD CONSTRAINT fk_ticket_history_priority_i54 FOREIGN KEY (priority_id) REFERENCES ticket_priority(id);
 ALTER TABLE ticket_history ADD CONSTRAINT fk_ticket_history_owner_id_id FOREIGN KEY (owner_id) REFERENCES system_user(id);
 ALTER TABLE ticket_history ADD CONSTRAINT fk_ticket_history_create_by_id FOREIGN KEY (create_by) REFERENCES system_user(id);
 ALTER TABLE ticket_history ADD CONSTRAINT fk_ticket_history_change_by_id FOREIGN KEY (change_by) REFERENCES system_user(id);
 ALTER TABLE ticket_history ADD CONSTRAINT fk_ticket_history_valid_id_id FOREIGN KEY (valid_id) REFERENCES valid(id);
 ALTER TABLE ticket_history ADD CONSTRAINT fk_ticket_history_state_id_id FOREIGN KEY (state_id) REFERENCES ticket_state(id);
-ALTER TABLE ticket_history ADD CONSTRAINT fk_ticket_history_history_type_id_id FOREIGN KEY (history_type_id) REFERENCES ticket_history_type(id);
-ALTER TABLE ticket_history ADD CONSTRAINT fk_ticket_history_article_id_id FOREIGN KEY (article_id) REFERENCES article(id);
+ALTER TABLE ticket_history ADD CONSTRAINT fk_ticket_history_history_ty90 FOREIGN KEY (history_type_id) REFERENCES ticket_history_type(id);
+ALTER TABLE ticket_history ADD CONSTRAINT fk_ticket_history_article_id57 FOREIGN KEY (article_id) REFERENCES article(id);
 ALTER TABLE ticket_history ADD CONSTRAINT fk_ticket_history_queue_id_id FOREIGN KEY (queue_id) REFERENCES queue(id);
 ALTER TABLE ticket_history ADD CONSTRAINT fk_ticket_history_ticket_id_id FOREIGN KEY (ticket_id) REFERENCES ticket(id);
-ALTER TABLE ticket_history_type ADD CONSTRAINT fk_ticket_history_type_create_by_id FOREIGN KEY (create_by) REFERENCES system_user(id);
-ALTER TABLE ticket_history_type ADD CONSTRAINT fk_ticket_history_type_change_by_id FOREIGN KEY (change_by) REFERENCES system_user(id);
-ALTER TABLE ticket_history_type ADD CONSTRAINT fk_ticket_history_type_valid_id_id FOREIGN KEY (valid_id) REFERENCES valid(id);
+ALTER TABLE ticket_history_type ADD CONSTRAINT fk_ticket_history_type_creat91 FOREIGN KEY (create_by) REFERENCES system_user(id);
+ALTER TABLE ticket_history_type ADD CONSTRAINT fk_ticket_history_type_chang22 FOREIGN KEY (change_by) REFERENCES system_user(id);
+ALTER TABLE ticket_history_type ADD CONSTRAINT fk_ticket_history_type_valid55 FOREIGN KEY (valid_id) REFERENCES valid(id);
 ALTER TABLE article_type ADD CONSTRAINT fk_article_type_create_by_id FOREIGN KEY (create_by) REFERENCES system_user(id);
 ALTER TABLE article_type ADD CONSTRAINT fk_article_type_change_by_id FOREIGN KEY (change_by) REFERENCES system_user(id);
 ALTER TABLE article_type ADD CONSTRAINT fk_article_type_valid_id_id FOREIGN KEY (valid_id) REFERENCES valid(id);
-ALTER TABLE article_sender_type ADD CONSTRAINT fk_article_sender_type_create_by_id FOREIGN KEY (create_by) REFERENCES system_user(id);
-ALTER TABLE article_sender_type ADD CONSTRAINT fk_article_sender_type_change_by_id FOREIGN KEY (change_by) REFERENCES system_user(id);
-ALTER TABLE article_sender_type ADD CONSTRAINT fk_article_sender_type_valid_id_id FOREIGN KEY (valid_id) REFERENCES valid(id);
+ALTER TABLE article_sender_type ADD CONSTRAINT fk_article_sender_type_creat1 FOREIGN KEY (create_by) REFERENCES system_user(id);
+ALTER TABLE article_sender_type ADD CONSTRAINT fk_article_sender_type_chang9 FOREIGN KEY (change_by) REFERENCES system_user(id);
+ALTER TABLE article_sender_type ADD CONSTRAINT fk_article_sender_type_valid39 FOREIGN KEY (valid_id) REFERENCES valid(id);
 ALTER TABLE article_flag ADD CONSTRAINT fk_article_flag_create_by_id FOREIGN KEY (create_by) REFERENCES system_user(id);
-ALTER TABLE article ADD CONSTRAINT fk_article_article_sender_type_id_id FOREIGN KEY (article_sender_type_id) REFERENCES article_sender_type(id);
+ALTER TABLE article ADD CONSTRAINT fk_article_article_sender_ty35 FOREIGN KEY (article_sender_type_id) REFERENCES article_sender_type(id);
 ALTER TABLE article ADD CONSTRAINT fk_article_create_by_id FOREIGN KEY (create_by) REFERENCES system_user(id);
 ALTER TABLE article ADD CONSTRAINT fk_article_change_by_id FOREIGN KEY (change_by) REFERENCES system_user(id);
 ALTER TABLE article ADD CONSTRAINT fk_article_valid_id_id FOREIGN KEY (valid_id) REFERENCES valid(id);
@@ -100,39 +100,39 @@ ALTER TABLE article ADD CONSTRAINT fk_article_ticket_id_id FOREIGN KEY (ticket_i
 ALTER TABLE article_plain ADD CONSTRAINT fk_article_plain_create_by_id FOREIGN KEY (create_by) REFERENCES system_user(id);
 ALTER TABLE article_plain ADD CONSTRAINT fk_article_plain_change_by_id FOREIGN KEY (change_by) REFERENCES system_user(id);
 ALTER TABLE article_plain ADD CONSTRAINT fk_article_plain_article_id_id FOREIGN KEY (article_id) REFERENCES article(id);
-ALTER TABLE article_attachment ADD CONSTRAINT fk_article_attachment_create_by_id FOREIGN KEY (create_by) REFERENCES system_user(id);
-ALTER TABLE article_attachment ADD CONSTRAINT fk_article_attachment_change_by_id FOREIGN KEY (change_by) REFERENCES system_user(id);
-ALTER TABLE article_attachment ADD CONSTRAINT fk_article_attachment_article_id_id FOREIGN KEY (article_id) REFERENCES article(id);
-ALTER TABLE standard_response ADD CONSTRAINT fk_standard_response_create_by_id FOREIGN KEY (create_by) REFERENCES system_user(id);
-ALTER TABLE standard_response ADD CONSTRAINT fk_standard_response_change_by_id FOREIGN KEY (change_by) REFERENCES system_user(id);
-ALTER TABLE standard_response ADD CONSTRAINT fk_standard_response_valid_id_id FOREIGN KEY (valid_id) REFERENCES valid(id);
-ALTER TABLE queue_standard_response ADD CONSTRAINT fk_queue_standard_response_create_by_id FOREIGN KEY (create_by) REFERENCES system_user(id);
-ALTER TABLE queue_standard_response ADD CONSTRAINT fk_queue_standard_response_change_by_id FOREIGN KEY (change_by) REFERENCES system_user(id);
-ALTER TABLE queue_standard_response ADD CONSTRAINT fk_queue_standard_response_standard_response_id_id FOREIGN KEY (standard_response_id) REFERENCES standard_response(id);
-ALTER TABLE queue_standard_response ADD CONSTRAINT fk_queue_standard_response_queue_id_id FOREIGN KEY (queue_id) REFERENCES queue(id);
-ALTER TABLE standard_attachment ADD CONSTRAINT fk_standard_attachment_create_by_id FOREIGN KEY (create_by) REFERENCES system_user(id);
-ALTER TABLE standard_attachment ADD CONSTRAINT fk_standard_attachment_change_by_id FOREIGN KEY (change_by) REFERENCES system_user(id);
-ALTER TABLE standard_attachment ADD CONSTRAINT fk_standard_attachment_valid_id_id FOREIGN KEY (valid_id) REFERENCES valid(id);
-ALTER TABLE standard_response_attachment ADD CONSTRAINT fk_standard_response_attachment_create_by_id FOREIGN KEY (create_by) REFERENCES system_user(id);
-ALTER TABLE standard_response_attachment ADD CONSTRAINT fk_standard_response_attachment_change_by_id FOREIGN KEY (change_by) REFERENCES system_user(id);
-ALTER TABLE standard_response_attachment ADD CONSTRAINT fk_standard_response_attachment_standard_response_id_id FOREIGN KEY (standard_response_id) REFERENCES standard_response(id);
-ALTER TABLE standard_response_attachment ADD CONSTRAINT fk_standard_response_attachment_standard_attachment_id_id FOREIGN KEY (standard_attachment_id) REFERENCES standard_attachment(id);
-ALTER TABLE auto_response_type ADD CONSTRAINT fk_auto_response_type_create_by_id FOREIGN KEY (create_by) REFERENCES system_user(id);
-ALTER TABLE auto_response_type ADD CONSTRAINT fk_auto_response_type_change_by_id FOREIGN KEY (change_by) REFERENCES system_user(id);
-ALTER TABLE auto_response_type ADD CONSTRAINT fk_auto_response_type_valid_id_id FOREIGN KEY (valid_id) REFERENCES valid(id);
+ALTER TABLE article_attachment ADD CONSTRAINT fk_article_attachment_create80 FOREIGN KEY (create_by) REFERENCES system_user(id);
+ALTER TABLE article_attachment ADD CONSTRAINT fk_article_attachment_change37 FOREIGN KEY (change_by) REFERENCES system_user(id);
+ALTER TABLE article_attachment ADD CONSTRAINT fk_article_attachment_articl76 FOREIGN KEY (article_id) REFERENCES article(id);
+ALTER TABLE standard_response ADD CONSTRAINT fk_standard_response_create_32 FOREIGN KEY (create_by) REFERENCES system_user(id);
+ALTER TABLE standard_response ADD CONSTRAINT fk_standard_response_change_84 FOREIGN KEY (change_by) REFERENCES system_user(id);
+ALTER TABLE standard_response ADD CONSTRAINT fk_standard_response_valid_i29 FOREIGN KEY (valid_id) REFERENCES valid(id);
+ALTER TABLE queue_standard_response ADD CONSTRAINT fk_queue_standard_response_c88 FOREIGN KEY (create_by) REFERENCES system_user(id);
+ALTER TABLE queue_standard_response ADD CONSTRAINT fk_queue_standard_response_c95 FOREIGN KEY (change_by) REFERENCES system_user(id);
+ALTER TABLE queue_standard_response ADD CONSTRAINT fk_queue_standard_response_s77 FOREIGN KEY (standard_response_id) REFERENCES standard_response(id);
+ALTER TABLE queue_standard_response ADD CONSTRAINT fk_queue_standard_response_q13 FOREIGN KEY (queue_id) REFERENCES queue(id);
+ALTER TABLE standard_attachment ADD CONSTRAINT fk_standard_attachment_creat55 FOREIGN KEY (create_by) REFERENCES system_user(id);
+ALTER TABLE standard_attachment ADD CONSTRAINT fk_standard_attachment_chang57 FOREIGN KEY (change_by) REFERENCES system_user(id);
+ALTER TABLE standard_attachment ADD CONSTRAINT fk_standard_attachment_valid17 FOREIGN KEY (valid_id) REFERENCES valid(id);
+ALTER TABLE standard_response_attachment ADD CONSTRAINT fk_standard_response_attachm88 FOREIGN KEY (create_by) REFERENCES system_user(id);
+ALTER TABLE standard_response_attachment ADD CONSTRAINT fk_standard_response_attachm50 FOREIGN KEY (change_by) REFERENCES system_user(id);
+ALTER TABLE standard_response_attachment ADD CONSTRAINT fk_standard_response_attachm2 FOREIGN KEY (standard_response_id) REFERENCES standard_response(id);
+ALTER TABLE standard_response_attachment ADD CONSTRAINT fk_standard_response_attachm83 FOREIGN KEY (standard_attachment_id) REFERENCES standard_attachment(id);
+ALTER TABLE auto_response_type ADD CONSTRAINT fk_auto_response_type_create44 FOREIGN KEY (create_by) REFERENCES system_user(id);
+ALTER TABLE auto_response_type ADD CONSTRAINT fk_auto_response_type_change59 FOREIGN KEY (change_by) REFERENCES system_user(id);
+ALTER TABLE auto_response_type ADD CONSTRAINT fk_auto_response_type_valid_39 FOREIGN KEY (valid_id) REFERENCES valid(id);
 ALTER TABLE auto_response ADD CONSTRAINT fk_auto_response_type_id_id FOREIGN KEY (type_id) REFERENCES auto_response_type(id);
-ALTER TABLE auto_response ADD CONSTRAINT fk_auto_response_system_address_id_id FOREIGN KEY (system_address_id) REFERENCES system_address(id);
+ALTER TABLE auto_response ADD CONSTRAINT fk_auto_response_system_addr30 FOREIGN KEY (system_address_id) REFERENCES system_address(id);
 ALTER TABLE auto_response ADD CONSTRAINT fk_auto_response_create_by_id FOREIGN KEY (create_by) REFERENCES system_user(id);
 ALTER TABLE auto_response ADD CONSTRAINT fk_auto_response_change_by_id FOREIGN KEY (change_by) REFERENCES system_user(id);
 ALTER TABLE auto_response ADD CONSTRAINT fk_auto_response_valid_id_id FOREIGN KEY (valid_id) REFERENCES valid(id);
-ALTER TABLE queue_auto_response ADD CONSTRAINT fk_queue_auto_response_auto_response_id_id FOREIGN KEY (auto_response_id) REFERENCES auto_response(id);
-ALTER TABLE queue_auto_response ADD CONSTRAINT fk_queue_auto_response_create_by_id FOREIGN KEY (create_by) REFERENCES system_user(id);
-ALTER TABLE queue_auto_response ADD CONSTRAINT fk_queue_auto_response_change_by_id FOREIGN KEY (change_by) REFERENCES system_user(id);
-ALTER TABLE queue_auto_response ADD CONSTRAINT fk_queue_auto_response_queue_id_id FOREIGN KEY (queue_id) REFERENCES queue(id);
-ALTER TABLE time_accounting ADD CONSTRAINT fk_time_accounting_create_by_id FOREIGN KEY (create_by) REFERENCES system_user(id);
-ALTER TABLE time_accounting ADD CONSTRAINT fk_time_accounting_change_by_id FOREIGN KEY (change_by) REFERENCES system_user(id);
-ALTER TABLE time_accounting ADD CONSTRAINT fk_time_accounting_article_id_id FOREIGN KEY (article_id) REFERENCES article(id);
-ALTER TABLE time_accounting ADD CONSTRAINT fk_time_accounting_ticket_id_id FOREIGN KEY (ticket_id) REFERENCES ticket(id);
+ALTER TABLE queue_auto_response ADD CONSTRAINT fk_queue_auto_response_auto_11 FOREIGN KEY (auto_response_id) REFERENCES auto_response(id);
+ALTER TABLE queue_auto_response ADD CONSTRAINT fk_queue_auto_response_creat72 FOREIGN KEY (create_by) REFERENCES system_user(id);
+ALTER TABLE queue_auto_response ADD CONSTRAINT fk_queue_auto_response_chang56 FOREIGN KEY (change_by) REFERENCES system_user(id);
+ALTER TABLE queue_auto_response ADD CONSTRAINT fk_queue_auto_response_queue95 FOREIGN KEY (queue_id) REFERENCES queue(id);
+ALTER TABLE time_accounting ADD CONSTRAINT fk_time_accounting_create_by32 FOREIGN KEY (create_by) REFERENCES system_user(id);
+ALTER TABLE time_accounting ADD CONSTRAINT fk_time_accounting_change_by18 FOREIGN KEY (change_by) REFERENCES system_user(id);
+ALTER TABLE time_accounting ADD CONSTRAINT fk_time_accounting_article_i26 FOREIGN KEY (article_id) REFERENCES article(id);
+ALTER TABLE time_accounting ADD CONSTRAINT fk_time_accounting_ticket_id15 FOREIGN KEY (ticket_id) REFERENCES ticket(id);
 ALTER TABLE customer_user ADD CONSTRAINT fk_customer_user_create_by_id FOREIGN KEY (create_by) REFERENCES system_user(id);
 ALTER TABLE customer_user ADD CONSTRAINT fk_customer_user_change_by_id FOREIGN KEY (change_by) REFERENCES system_user(id);
 ALTER TABLE customer_user ADD CONSTRAINT fk_customer_user_valid_id_id FOREIGN KEY (valid_id) REFERENCES valid(id);
@@ -155,5 +155,5 @@ ALTER TABLE faq_state ADD CONSTRAINT fk_faq_state_type_id_id FOREIGN KEY (type_i
 ALTER TABLE faq_attachment ADD CONSTRAINT fk_faq_attachment_create_by_id FOREIGN KEY (create_by) REFERENCES system_user(id);
 ALTER TABLE faq_attachment ADD CONSTRAINT fk_faq_attachment_change_by_id FOREIGN KEY (change_by) REFERENCES system_user(id);
 ALTER TABLE faq_attachment ADD CONSTRAINT fk_faq_attachment_faq_id_id FOREIGN KEY (faq_id) REFERENCES faq_item(id);
-ALTER TABLE package_repository ADD CONSTRAINT fk_package_repository_create_by_id FOREIGN KEY (create_by) REFERENCES system_user(id);
-ALTER TABLE package_repository ADD CONSTRAINT fk_package_repository_change_by_id FOREIGN KEY (change_by) REFERENCES system_user(id);
+ALTER TABLE package_repository ADD CONSTRAINT fk_package_repository_create82 FOREIGN KEY (create_by) REFERENCES system_user(id);
+ALTER TABLE package_repository ADD CONSTRAINT fk_package_repository_change82 FOREIGN KEY (change_by) REFERENCES system_user(id);
